@@ -17,5 +17,7 @@ def filter():
   "id": "123",
   "score": 1.6,
   "ips": "192.168.2.1, 10.0.0.20, 10.0.0.10",
-  "json": "{\\"message\\": \\"Hello\\"}"
+  "json": "{\\"message\\": \\"Hello\\"}",
+  "pi": "3.141592653589793",
+  "ten": 10
 }"""
