@@ -25,7 +25,7 @@ use std::{env, fs, io};
 use clap::ArgMatches;
 use hurl::runner::Value;
 use hurl_core::input::Input;
-use hurl_core::typing::{Count, DurationUnit};
+use hurl_core::typing::{BytesPerSec, Count, DurationUnit};
 
 use crate::cli::options::variables::{parse as parse_variable, parse_value};
 use crate::cli::options::{duration, CliOptionsError};
@@ -111,10 +111,6 @@ pub fn connects_to(arg_matches: &ArgMatches) -> Vec<String> {
 }
 
 pub fn continue_on_error(arg_matches: &ArgMatches) -> bool {
-    if has_flag(arg_matches, "fail_at_end") {
-        eprintln!("The option fail-at-end is deprecated. Use continue-on-error instead");
-        return true;
-    }
     has_flag(arg_matches, "continue_on_error")
 }
 
@@ -126,6 +122,10 @@ pub fn cookie_output_file(arg_matches: &ArgMatches) -> Option<PathBuf> {
     get::<String>(arg_matches, "cookies_output_file").map(PathBuf::from)
 }
 
+pub fn curl_file(arg_matches: &ArgMatches) -> Option<PathBuf> {
+    get::<String>(arg_matches, "curl").map(PathBuf::from)
+}
+
 pub fn delay(arg_matches: &ArgMatches) -> Result<Duration, CliOptionsError> {
     let s = get::<String>(arg_matches, "delay").unwrap_or_default();
     get_duration(&s, DurationUnit::MilliSecond)
@@ -230,7 +230,11 @@ pub fn input_files(arg_matches: &ArgMatches) -> Result<Vec<Input>, CliOptionsErr
         files.push(filename);
     }
     if files.is_empty() && !io::stdin().is_terminal() {
-        files.push(Input::Stdin);
+        let input = match Input::from_stdin() {
+            Ok(input) => input,
+            Err(err) => return Err(CliOptionsError::Error(err.to_string())),
+        };
+        files.push(input);
     }
     Ok(files)
 }
@@ -276,6 +280,14 @@ pub fn junit_file(arg_matches: &ArgMatches) -> Option<PathBuf> {
     get::<String>(arg_matches, "report_junit").map(PathBuf::from)
 }
 
+pub fn limit_rate(arg_matches: &ArgMatches) -> Option<BytesPerSec> {
+    get::<u64>(arg_matches, "limit_rate").map(BytesPerSec)
+}
+
+pub fn max_filesize(arg_matches: &ArgMatches) -> Option<u64> {
+    get::<u64>(arg_matches, "max_filesize")
+}
+
 pub fn max_redirect(arg_matches: &ArgMatches) -> Count {
     match get::<i32>(arg_matches, "max_redirects").unwrap() {
         -1 => Count::Infinite,
@@ -488,10 +500,6 @@ pub fn very_verbose(arg_matches: &ArgMatches) -> bool {
     has_flag(arg_matches, "very_verbose")
 }
 
-pub fn max_filesize(arg_matches: &ArgMatches) -> Option<u64> {
-    get::<u64>(arg_matches, "max_filesize")
-}
-
 /// Returns a list of path names from the command line options `matches`.
 fn glob_files(matches: &ArgMatches) -> Result<Vec<Input>, CliOptionsError> {
     let mut all_files = vec![];
