@@ -34,8 +34,8 @@ use hurl::runner::Output;
 use hurl::util::logger::{LoggerOptions, LoggerOptionsBuilder, Verbosity};
 use hurl::util::path::ContextDir;
 use hurl_core::ast::Entry;
-use hurl_core::input::Input;
-use hurl_core::typing::Count;
+use hurl_core::input::{Input, InputKind};
+use hurl_core::typing::{BytesPerSec, Count};
 
 use crate::cli;
 use crate::runner::{RunnerOptions, RunnerOptionsBuilder, Value};
@@ -54,6 +54,7 @@ pub struct CliOptions {
     pub continue_on_error: bool,
     pub cookie_input_file: Option<String>,
     pub cookie_output_file: Option<PathBuf>,
+    pub curl_file: Option<PathBuf>,
     pub delay: Duration,
     pub error_format: ErrorFormat,
     pub file_root: Option<String>,
@@ -71,6 +72,7 @@ pub struct CliOptions {
     pub jobs: Option<usize>,
     pub json_report_dir: Option<PathBuf>,
     pub junit_file: Option<PathBuf>,
+    pub limit_rate: Option<BytesPerSec>,
     pub max_filesize: Option<u64>,
     pub max_redirect: Count,
     pub netrc: bool,
@@ -168,69 +170,76 @@ pub fn parse() -> Result<CliOptions, CliOptionsError> {
         .version(get_version())
         .disable_colored_help(true)
         .about("Hurl, run and test HTTP requests with plain text")
+        // HTTP options
         .arg(commands::aws_sigv4())
         .arg(commands::cacert_file())
         .arg(commands::client_cert_file())
-        .arg(commands::client_key_file())
-        .arg(commands::color())
         .arg(commands::compressed())
         .arg(commands::connect_timeout())
         .arg(commands::connect_to())
-        .arg(commands::continue_on_error())
-        .arg(commands::cookies_input_file())
-        .arg(commands::cookies_output_file())
-        .arg(commands::delay())
-        .arg(commands::error_format())
-        .arg(commands::fail_at_end())
-        .arg(commands::file_root())
-        .arg(commands::follow_location())
-        .arg(commands::follow_location_trusted())
-        .arg(commands::from_entry())
-        .arg(commands::glob())
         .arg(commands::http10())
         .arg(commands::http11())
         .arg(commands::http2())
         .arg(commands::http3())
-        .arg(commands::ignore_asserts())
-        .arg(commands::include())
         .arg(commands::input_files())
         .arg(commands::insecure())
-        .arg(commands::interactive())
         .arg(commands::ipv4())
         .arg(commands::ipv6())
-        .arg(commands::jobs())
-        .arg(commands::json())
+        .arg(commands::client_key_file())
+        .arg(commands::limit_rate())
+        .arg(commands::follow_location())
+        .arg(commands::follow_location_trusted())
         .arg(commands::max_filesize())
         .arg(commands::max_redirects())
         .arg(commands::max_time())
-        .arg(commands::netrc())
-        .arg(commands::netrc_file())
-        .arg(commands::netrc_optional())
-        .arg(commands::no_color())
-        .arg(commands::no_output())
         .arg(commands::noproxy())
-        .arg(commands::output())
-        .arg(commands::parallel())
         .arg(commands::path_as_is())
         .arg(commands::proxy())
+        .arg(commands::resolve())
+        .arg(commands::ssl_no_revoke())
+        .arg(commands::unix_socket())
+        .arg(commands::user())
+        .arg(commands::user_agent())
+        // Output options
+        .arg(commands::color())
+        .arg(commands::curl())
+        .arg(commands::error_format())
+        .arg(commands::include())
+        .arg(commands::json())
+        .arg(commands::no_color())
+        .arg(commands::no_output())
+        .arg(commands::output())
+        .arg(commands::verbose())
+        .arg(commands::very_verbose())
+        // Run options
+        .arg(commands::continue_on_error())
+        .arg(commands::delay())
+        .arg(commands::from_entry())
+        .arg(commands::ignore_asserts())
+        .arg(commands::interactive())
+        .arg(commands::jobs())
+        .arg(commands::parallel())
         .arg(commands::repeat())
+        .arg(commands::retry())
+        .arg(commands::retry_interval())
+        .arg(commands::test())
+        .arg(commands::to_entry())
+        .arg(commands::variable())
+        .arg(commands::variables_file())
+        // Report options
         .arg(commands::report_html())
         .arg(commands::report_json())
         .arg(commands::report_junit())
         .arg(commands::report_tap())
-        .arg(commands::resolve())
-        .arg(commands::retry())
-        .arg(commands::retry_interval())
-        .arg(commands::ssl_no_revoke())
-        .arg(commands::test())
-        .arg(commands::to_entry())
-        .arg(commands::unix_socket())
-        .arg(commands::user_agent())
-        .arg(commands::user())
-        .arg(commands::variable())
-        .arg(commands::variables_file())
-        .arg(commands::verbose())
-        .arg(commands::very_verbose());
+        // Other options
+        .arg(commands::cookies_input_file())
+        .arg(commands::cookies_output_file())
+        .arg(commands::file_root())
+        .arg(commands::glob())
+        .arg(commands::netrc())
+        .arg(commands::netrc_file())
+        .arg(commands::netrc_optional());
+
     let arg_matches = command.try_get_matches_from_mut(env::args_os())?;
 
     // If we've no file input (either from the standard input or from the command line arguments),
@@ -267,6 +276,7 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<CliOptions, CliOptionsError
     let continue_on_error = matches::continue_on_error(arg_matches);
     let cookie_input_file = matches::cookie_input_file(arg_matches);
     let cookie_output_file = matches::cookie_output_file(arg_matches);
+    let curl_file = matches::curl_file(arg_matches);
     let delay = matches::delay(arg_matches)?;
     let error_format = matches::error_format(arg_matches);
     let file_root = matches::file_root(arg_matches);
@@ -282,6 +292,7 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<CliOptions, CliOptionsError
     let ip_resolve = matches::ip_resolve(arg_matches);
     let json_report_dir = matches::json_report_dir(arg_matches)?;
     let junit_file = matches::junit_file(arg_matches);
+    let limit_rate = matches::limit_rate(arg_matches);
     let max_filesize = matches::max_filesize(arg_matches);
     let max_redirect = matches::max_redirect(arg_matches);
     let netrc = matches::netrc(arg_matches);
@@ -322,6 +333,7 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<CliOptions, CliOptionsError
         continue_on_error,
         cookie_input_file,
         cookie_output_file,
+        curl_file,
         delay,
         error_format,
         file_root,
@@ -338,6 +350,7 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<CliOptions, CliOptionsError
         ip_resolve,
         json_report_dir,
         junit_file,
+        limit_rate,
         max_filesize,
         max_redirect,
         netrc,
@@ -390,9 +403,9 @@ impl CliOptions {
         let connects_to = self.connects_to.clone();
         let file_root = match &self.file_root {
             Some(f) => Path::new(f),
-            None => match filename {
-                Input::File(path) => path.parent().unwrap(),
-                Input::Stdin => current_dir,
+            None => match filename.kind() {
+                InputKind::File(path) => path.parent().unwrap(),
+                InputKind::Stdin(_) => current_dir,
             },
         };
         let context_dir = ContextDir::new(current_dir, file_root);
@@ -413,6 +426,10 @@ impl CliOptions {
             None => http::IpResolve::default(),
         };
         let max_filesize = self.max_filesize;
+        // Like curl, we don't differentiate upload and download limit rate, we have
+        // only one option.
+        let max_recv_speed = self.limit_rate;
+        let max_send_speed = self.limit_rate;
         let max_redirect = self.max_redirect;
         let netrc = self.netrc;
         let netrc_file = self.netrc_file.clone();
@@ -461,7 +478,9 @@ impl CliOptions {
             .insecure(insecure)
             .ip_resolve(ip_resolve)
             .max_filesize(max_filesize)
+            .max_recv_speed(max_recv_speed)
             .max_redirect(max_redirect)
+            .max_send_speed(max_send_speed)
             .netrc(netrc)
             .netrc_file(netrc_file)
             .netrc_optional(netrc_optional)
