@@ -30,18 +30,19 @@ use encoding::{DecoderTrap, Encoding};
 use hurl_core::typing::Count;
 
 use crate::http::certificate::Certificate;
-use crate::http::core::*;
+use crate::http::curl_cmd::CurlCmd;
 use crate::http::debug::log_body;
 use crate::http::header::{
     HeaderVec, ACCEPT_ENCODING, AUTHORIZATION, CONTENT_TYPE, EXPECT, LOCATION, USER_AGENT,
 };
 use crate::http::options::ClientOptions;
-use crate::http::request::*;
-use crate::http::request_spec::*;
-use crate::http::response::*;
 use crate::http::timings::Timings;
 use crate::http::url::Url;
-use crate::http::{easy_ext, Call, Header, HttpError, Verbosity};
+use crate::http::{
+    easy_ext, Call, Cookie, FileParam, Header, HttpError, HttpVersion, IpResolve, Method,
+    MultipartParam, Param, Request, RequestCookie, RequestSpec, RequestedHttpVersion, Response,
+    Verbosity,
+};
 use crate::runner::Output;
 use crate::util::logger::Logger;
 use crate::util::path::ContextDir;
@@ -120,11 +121,16 @@ impl Client {
         let mut redirect_count = 0;
         loop {
             let call = self.execute(&request_spec, &options, logger)?;
+            // If we don't follow redirection, we can early exit here.
+            if !options.follow_location {
+                calls.push(call);
+                break;
+            }
             let request_url = call.request.url.clone();
-            let redirect_url = self.follow_location(&request_url, &call.response)?;
             let status = call.response.status;
+            let redirect_url = self.follow_location(&request_url, &call.response)?;
             calls.push(call);
-            if !options.follow_location || redirect_url.is_none() {
+            if redirect_url.is_none() {
                 break;
             }
             let redirect_url = redirect_url.unwrap();
@@ -150,7 +156,7 @@ impl Client {
             }
             request_spec = RequestSpec {
                 method: redirect_method,
-                url: redirect_url.to_string(),
+                url: redirect_url,
                 headers,
                 ..Default::default()
             };
@@ -271,6 +277,19 @@ impl Client {
             }
         }
 
+        // We perform an additional check on the response size if maximum filesize is specified
+        // because curl can fail to do this under certain circumstances.
+        // See:
+        // - <https://github.com/Orange-OpenSource/hurl/issues/3245>
+        // - <https://curl.se/docs/manpage.html#--max-filesize>
+        // > Note: before curl 8.4.0, when the file size is not known prior to download, for such files
+        // > this option has no effect even if the file transfer ends up being larger than this given limit.
+        if let Some(max_filesize) = options.max_filesize {
+            if response_body.len() as u64 > max_filesize {
+                return Err(HttpError::AllowedResponseSizeExceeded(max_filesize));
+            }
+        }
+
         let status = self.handle.response_code()?;
         // TODO: explain why status_lines is Vec ?
         let version = match status_lines.last() {
@@ -451,6 +470,12 @@ impl Client {
         if let Some(max_filesize) = options.max_filesize {
             self.handle.max_filesize(max_filesize)?;
         }
+        if let Some(max_recv_speed) = options.max_recv_speed {
+            self.handle.max_recv_speed(max_recv_speed.0)?;
+        }
+        if let Some(max_send_speed) = options.max_send_speed {
+            self.handle.max_send_speed(max_send_speed.0)?;
+        }
 
         self.set_ssl_options(options.ssl_no_revoke)?;
 
@@ -482,12 +507,13 @@ impl Client {
     }
 
     /// Generates URL.
-    fn generate_url(&mut self, url: &str, params: &[Param]) -> String {
+    fn generate_url(&mut self, url: &Url, params: &[Param]) -> String {
+        let url = url.raw();
         if params.is_empty() {
-            url.to_string()
+            url
         } else {
             let url = if url.ends_with('?') {
-                url.to_string()
+                url
             } else if url.contains('?') {
                 format!("{url}&")
             } else {
@@ -741,44 +767,9 @@ impl Client {
         context_dir: &ContextDir,
         output: Option<&Output>,
         options: &ClientOptions,
-    ) -> String {
-        let mut arguments = vec!["curl".to_string()];
-        arguments.append(&mut request_spec.curl_args(context_dir));
-
-        // We extract the last part of the arguments (the url) to insert it
-        // after all the options
-        let url = arguments.pop().unwrap();
-
-        let cookies = all_cookies(&self.cookie_storage(), request_spec);
-        if !cookies.is_empty() {
-            arguments.push("--cookie".to_string());
-            arguments.push(format!(
-                "'{}'",
-                cookies
-                    .iter()
-                    .map(|c| c.to_string())
-                    .collect::<Vec<String>>()
-                    .join("; ")
-            ));
-        }
-        arguments.append(&mut options.curl_args());
-
-        // --output is not an option of the HTTP client, we deal with it here:
-        match output {
-            Some(Output::File(filename)) => {
-                let filename = context_dir.resolved_path(filename);
-                arguments.push("--output".to_string());
-                arguments.push(filename.to_string_lossy().to_string());
-            }
-            Some(Output::Stdout) => {
-                arguments.push("--output".to_string());
-                arguments.push("-".to_string());
-            }
-            None => {}
-        }
-
-        arguments.push(url);
-        arguments.join(" ")
+    ) -> CurlCmd {
+        let cookies = self.cookie_storage();
+        CurlCmd::new(request_spec, &cookies, context_dir, output, options)
     }
 
     /// Returns the SSL certificates information associated to this call.
@@ -833,7 +824,7 @@ pub fn all_cookies(cookie_storage: &[Cookie], request_spec: &RequestSpec) -> Vec
         &mut cookie_storage
             .iter()
             .filter(|c| c.expires != "1") // cookie expired when libcurl set value to 1?
-            .filter(|c| match_cookie(c, request_spec.url.as_str()))
+            .filter(|c| match_cookie(c, &request_spec.url))
             .map(|c| RequestCookie {
                 name: c.name.clone(),
                 value: c.value.clone(),
@@ -844,12 +835,7 @@ pub fn all_cookies(cookie_storage: &[Cookie], request_spec: &RequestSpec) -> Vec
 }
 
 /// Matches cookie for a given URL.
-pub fn match_cookie(cookie: &Cookie, url: &str) -> bool {
-    // FIXME: is it possible to do it with libcurl?
-    let url = match url::Url::parse(url) {
-        Ok(url) => url,
-        Err(_) => return false,
-    };
+pub fn match_cookie(cookie: &Cookie, url: &Url) -> bool {
     if let Some(domain) = url.domain() {
         if cookie.include_subdomain == "FALSE" {
             if cookie.domain != domain {
@@ -1026,9 +1012,18 @@ mod tests {
             value: String::new(),
             http_only: false,
         };
-        assert!(match_cookie(&cookie, "http://example.com/toto"));
-        assert!(!match_cookie(&cookie, "http://sub.example.com/tata"));
-        assert!(!match_cookie(&cookie, "http://toto/tata"));
+        assert!(match_cookie(
+            &cookie,
+            &Url::from_str("http://example.com/toto").unwrap()
+        ));
+        assert!(!match_cookie(
+            &cookie,
+            &Url::from_str("http://sub.example.com/tata").unwrap()
+        ));
+        assert!(!match_cookie(
+            &cookie,
+            &Url::from_str("http://toto/tata").unwrap()
+        ));
 
         let cookie = Cookie {
             domain: "example.com".to_string(),
@@ -1040,9 +1035,18 @@ mod tests {
             value: String::new(),
             http_only: false,
         };
-        assert!(match_cookie(&cookie, "http://example.com/toto"));
-        assert!(match_cookie(&cookie, "http://sub.example.com/toto"));
-        assert!(!match_cookie(&cookie, "http://example.com/tata"));
+        assert!(match_cookie(
+            &cookie,
+            &Url::from_str("http://example.com/toto").unwrap()
+        ));
+        assert!(match_cookie(
+            &cookie,
+            &Url::from_str("http://sub.example.com/toto").unwrap()
+        ));
+        assert!(!match_cookie(
+            &cookie,
+            &Url::from_str("http://example.com/tata").unwrap()
+        ));
     }
 
     #[test]
@@ -1138,7 +1142,7 @@ mod tests {
         let mut client = Client::new();
         let request = RequestSpec {
             method: Method("GET".to_string()),
-            url: "https://example.org".to_string(),
+            url: Url::from_str("https://example.org").unwrap(),
             ..Default::default()
         };
         let context_dir = ContextDir::default();
@@ -1163,7 +1167,7 @@ mod tests {
 
         let cmd = client.curl_command_line(&request, &context_dir, output, &options);
         assert_eq!(
-            cmd,
+            cmd.to_string(),
             "curl \
          --aws-sigv4 aws:amz:sts \
          --cacert /etc/cert.pem \
