@@ -27,11 +27,15 @@ use encoding::DecoderTrap;
 
 use crate::http::{mimetype, HttpError, Response};
 
-#[derive(Clone, Debug, PartialEq, Eq)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum ContentEncoding {
+    /// A format using the Brotli algorithm structure (defined in RFC 7932).
     Brotli,
+    /// A format using the Lempel-Ziv coding (LZ77), with a 32-bit CRC.
     Gzip,
+    /// Using the zlib structure (defined in RFC 1950) with the deflate compression algorithm.
     Deflate,
+    /// No encoding.
     Identity,
 }
 
@@ -63,12 +67,17 @@ impl ContentEncoding {
 impl Response {
     /// Returns response body as text.
     pub fn text(&self) -> Result<String, HttpError> {
-        let encoding = self.headers.character_encoding()?;
-        let body = &self.uncompress_body()?;
-        match encoding.decode(body, DecoderTrap::Strict) {
+        let content_encodings = self.headers.content_encoding()?;
+        let body = if content_encodings.is_empty() {
+            &self.body
+        } else {
+            &self.uncompress_body()?
+        };
+        let character_encoding = self.headers.character_encoding()?;
+        match character_encoding.decode(body, DecoderTrap::Strict) {
             Ok(s) => Ok(s),
             Err(_) => Err(HttpError::InvalidDecoding {
-                charset: encoding.name().to_string(),
+                charset: character_encoding.name().to_string(),
             }),
         }
     }
@@ -78,6 +87,16 @@ impl Response {
         self.headers.content_type().map_or(false, mimetype::is_html)
     }
 
+    /// Returns true if response is a JSON response.
+    pub fn is_json(&self) -> bool {
+        self.headers.content_type().map_or(false, mimetype::is_json)
+    }
+
+    /// Returns true if response is a XML response.
+    pub fn is_xml(&self) -> bool {
+        self.headers.content_type().map_or(false, mimetype::is_xml)
+    }
+
     /// Decompresses HTTP body response.
     pub fn uncompress_body(&self) -> Result<Vec<u8>, HttpError> {
         let encodings = self.headers.content_encoding()?;
@@ -143,7 +162,19 @@ fn uncompress_zlib(data: &[u8]) -> Result<Vec<u8>, HttpError> {
 #[cfg(test)]
 pub mod tests {
     use super::*;
-    use crate::http::{Header, HeaderVec, Response};
+    use crate::http::{Header, HeaderVec, HttpVersion, Response};
+
+    fn default_response() -> Response {
+        Response {
+            version: HttpVersion::Http10,
+            status: 200,
+            headers: HeaderVec::new(),
+            body: vec![],
+            duration: Default::default(),
+            url: "http://localhost".parse().unwrap(),
+            certificate: None,
+        }
+    }
 
     #[test]
     fn test_parse_content_encoding() {
@@ -161,7 +192,7 @@ pub mod tests {
 
     #[test]
     fn test_content_encoding() {
-        let response = Response::default();
+        let response = default_response();
         assert_eq!(response.headers.content_encoding().unwrap(), vec![]);
 
         let mut headers = HeaderVec::new();
@@ -169,7 +200,7 @@ pub mod tests {
 
         let response = Response {
             headers,
-            ..Default::default()
+            ..default_response()
         };
         assert_eq!(
             response.headers.content_encoding().err().unwrap(),
@@ -183,7 +214,7 @@ pub mod tests {
 
         let response = Response {
             headers,
-            ..Default::default()
+            ..default_response()
         };
         assert_eq!(
             response.headers.content_encoding().unwrap(),
@@ -197,7 +228,7 @@ pub mod tests {
         headers.push(Header::new("Content-Encoding", "br, identity"));
         let response = Response {
             headers,
-            ..Default::default()
+            ..default_response()
         };
         assert_eq!(
             response.headers.content_encoding().unwrap(),
@@ -216,7 +247,7 @@ pub mod tests {
                 0x21, 0x2c, 0x00, 0x04, 0x48, 0x65, 0x6c, 0x6c, 0x6f, 0x20, 0x57, 0x6f, 0x72, 0x6c,
                 0x64, 0x21, 0x03,
             ],
-            ..Default::default()
+            ..default_response()
         };
         assert_eq!(response.uncompress_body().unwrap(), b"Hello World!");
 
@@ -228,13 +259,13 @@ pub mod tests {
                 0x21, 0x2c, 0x00, 0x04, 0x48, 0x65, 0x6c, 0x6c, 0x6f, 0x20, 0x57, 0x6f, 0x72, 0x6c,
                 0x64, 0x21, 0x03,
             ],
-            ..Default::default()
+            ..default_response()
         };
         assert_eq!(response.uncompress_body().unwrap(), b"Hello World!");
 
         let response = Response {
             body: b"Hello World!".to_vec(),
-            ..Default::default()
+            ..default_response()
         };
         assert_eq!(response.uncompress_body().unwrap(), b"Hello World!");
     }
@@ -287,7 +318,7 @@ pub mod tests {
     fn hello_response() -> Response {
         Response {
             body: b"Hello World!".to_vec(),
-            ..Default::default()
+            ..default_response()
         }
     }
 
@@ -298,7 +329,7 @@ pub mod tests {
         Response {
             headers,
             body: vec![0x63, 0x61, 0x66, 0xc3, 0xa9],
-            ..Default::default()
+            ..default_response()
         }
     }
 
@@ -312,7 +343,7 @@ pub mod tests {
         Response {
             headers,
             body: vec![0x63, 0x61, 0x66, 0xe9],
-            ..Default::default()
+            ..default_response()
         }
     }
 
@@ -376,7 +407,7 @@ pub mod tests {
             Response {
                 headers,
                 body: b"Hello World!".to_vec(),
-                ..Default::default()
+                ..default_response()
             }
             .headers
             .character_encoding()
@@ -393,7 +424,7 @@ pub mod tests {
         assert_eq!(
             Response {
                 body: vec![0x63, 0x61, 0x66, 0xe9],
-                ..Default::default()
+                ..default_response()
             }
             .text()
             .err()
@@ -413,7 +444,7 @@ pub mod tests {
             Response {
                 headers,
                 body: vec![0x63, 0x61, 0x66, 0xc3, 0xa9],
-                ..Default::default()
+                ..default_response()
             }
             .text()
             .unwrap(),
