@@ -21,7 +21,8 @@ use hurl_core::reader::Reader;
 use crate::jsonpath::ast::{Predicate, PredicateFunc, Query, Selector, Slice};
 use crate::jsonpath::parser::error::{ParseError, ParseErrorKind, ParseResult};
 use crate::jsonpath::parser::primitives::{
-    integer, key_name, key_path, literal, natural, number, string_value, try_literal, whitespace,
+    boolean, integer, key_name, key_path, literal, natural, number, string_value, try_literal,
+    whitespace,
 };
 
 pub fn parse(s: &str) -> Result<Query, ParseError> {
@@ -229,7 +230,10 @@ fn predicate_func(reader: &mut Reader) -> ParseResult<PredicateFunc> {
             greater_than_or_equal_predicate_func,
             less_than_predicate_func,
             less_than_or_equal_predicate_func,
+            equal_boolean_predicate_func,
             equal_string_predicate_func,
+            notequal_string_predicate_func,
+            notequal_number_func,
         ],
         reader,
     )
@@ -242,6 +246,13 @@ fn equal_number_predicate_func(reader: &mut Reader) -> ParseResult<PredicateFunc
     Ok(PredicateFunc::Equal(num))
 }
 
+fn equal_boolean_predicate_func(reader: &mut Reader) -> ParseResult<PredicateFunc> {
+    try_literal("==", reader)?;
+    whitespace(reader);
+    let boolean = boolean(reader)?;
+    Ok(PredicateFunc::EqualBool(boolean))
+}
+
 fn greater_than_predicate_func(reader: &mut Reader) -> ParseResult<PredicateFunc> {
     try_literal(">", reader)?;
     whitespace(reader);
@@ -277,6 +288,20 @@ fn equal_string_predicate_func(reader: &mut Reader) -> ParseResult<PredicateFunc
     Ok(PredicateFunc::EqualString(s))
 }
 
+fn notequal_string_predicate_func(reader: &mut Reader) -> ParseResult<PredicateFunc> {
+    try_literal("!=", reader)?;
+    whitespace(reader);
+    let s = string_value(reader)?;
+    Ok(PredicateFunc::NotEqualString(s))
+}
+
+fn notequal_number_func(reader: &mut Reader) -> ParseResult<PredicateFunc> {
+    try_literal("!=", reader)?;
+    whitespace(reader);
+    let num = number(reader)?;
+    Ok(PredicateFunc::NotEqual(num))
+}
+
 #[cfg(test)]
 mod tests {
     use hurl_core::reader::Pos;
@@ -580,6 +605,20 @@ mod tests {
 
     #[test]
     pub fn test_predicate_func() {
+        let mut reader = Reader::new("==true");
+        assert_eq!(
+            predicate_func(&mut reader).unwrap(),
+            PredicateFunc::EqualBool(true)
+        );
+        assert_eq!(reader.cursor().index, 6);
+
+        let mut reader = Reader::new("==false");
+        assert_eq!(
+            predicate_func(&mut reader).unwrap(),
+            PredicateFunc::EqualBool(false)
+        );
+        assert_eq!(reader.cursor().index, 7);
+
         let mut reader = Reader::new("==2");
         assert_eq!(
             predicate_func(&mut reader).unwrap(),
@@ -614,6 +653,27 @@ mod tests {
         );
         assert_eq!(reader.cursor().index, 9);
 
+        let mut reader = Reader::new("!='hello'");
+        assert_eq!(
+            predicate_func(&mut reader).unwrap(),
+            PredicateFunc::NotEqualString("hello".to_string())
+        );
+
+        let mut reader = Reader::new("!=2");
+        assert_eq!(
+            predicate_func(&mut reader).unwrap(),
+            PredicateFunc::NotEqual(Number { int: 2, decimal: 0 })
+        );
+
+        let mut reader = Reader::new("!=2.5");
+        assert_eq!(
+            predicate_func(&mut reader).unwrap(),
+            PredicateFunc::NotEqual(Number {
+                int: 2,
+                decimal: 500_000_000_000_000_000
+            })
+        );
+
         let mut reader = Reader::new(">5");
         assert_eq!(
             predicate_func(&mut reader).unwrap(),
