@@ -20,13 +20,13 @@
 //! There are two supported serialisation:
 //!
 //! - JSON: the whole run is serialized to JSON (like the [HAR](https://en.wikipedia.org/wiki/HAR_(file_format)) format)
-//! [`self::json::write_json`]
+//!   [`self::json::write_json`]
 //! - raw: the last response of a run is serialized to a file. The body can be automatically uncompress
-//! or written as it [`self::raw::write_last_body`]
+//!   or written as it [`self::raw::write_last_body`]
 mod error;
 mod json;
 mod raw;
 
-pub use self::error::Error;
+pub use self::error::OutputError;
 pub use self::json::write_json;
 pub use self::raw::write_last_body;
