@@ -34,6 +34,8 @@ use crate::util::term::{Stderr, Stdout, WriteMode};
 pub struct Worker {
     /// The id of this worker.
     worker_id: WorkerId,
+    /// The thread handle of this worker.
+    thread: Option<thread::JoinHandle<()>>,
 }
 
 impl fmt::Display for Worker {
@@ -72,9 +74,9 @@ impl Worker {
         let rx = Arc::clone(rx);
         let tx = tx.clone();
 
-        thread::spawn(move || loop {
+        let thread = thread::spawn(move || loop {
             let Ok(job) = rx.lock().unwrap().recv() else {
-                return tx.send(WorkerMessage::ShutDown);
+                return;
             };
             // In parallel execution, standard output and standard error messages are buffered
             // (in sequential mode, we'll use immediate standard output and error).
@@ -93,7 +95,8 @@ impl Worker {
                 Ok(c) => c,
                 Err(e) => {
                     let msg = IOErrorMsg::new(worker_id, &job, e);
-                    return tx.send(WorkerMessage::IOError(msg));
+                    _ = tx.send(WorkerMessage::IOError(msg));
+                    return;
                 }
             };
 
@@ -104,7 +107,8 @@ impl Worker {
                 Err(e) => {
                     logger.error_parsing_rich(&content, Some(&job.filename), &e);
                     let msg = ParsingErrorMsg::new(worker_id, &job, &logger.stderr);
-                    return tx.send(WorkerMessage::ParsingError(msg));
+                    _ = tx.send(WorkerMessage::ParsingError(msg));
+                    return;
                 }
             };
 
@@ -131,7 +135,15 @@ impl Worker {
             _ = tx.send(WorkerMessage::Completed(msg));
         });
 
-        Worker { worker_id }
+        Worker {
+            worker_id,
+            thread: Some(thread),
+        }
+    }
+
+    /// Takes the thread out of the worker, leaving a None in its place.
+    pub fn take_thread(&mut self) -> Option<thread::JoinHandle<()>> {
+        self.thread.take()
     }
 }
 
