@@ -97,7 +97,7 @@ mod test {
     use hurl_core::input::Input;
     use hurl_core::reader::Pos;
 
-    use crate::http::HttpError;
+    use crate::http::{CurlCmd, HttpError};
     use crate::report::junit::testcase::Testcase;
     use crate::report::junit::xml::XmlDocument;
     use crate::runner::{EntryResult, HurlResult, RunnerError, RunnerErrorKind};
@@ -118,7 +118,7 @@ mod test {
         let doc = XmlDocument::new(element);
         assert_eq!(
             doc.to_string().unwrap(),
-            r#"<?xml version="1.0" encoding="utf-8"?><testcase id="test.hurl" name="test.hurl" time="0.230" />"#
+            r#"<?xml version="1.0" encoding="UTF-8"?><testcase id="test.hurl" name="test.hurl" time="0.230" />"#
         );
     }
 
@@ -144,6 +144,7 @@ HTTP/1.0 200
                 )],
                 transfer_duration: Duration::from_millis(0),
                 compressed: false,
+                curl_cmd: CurlCmd::default(),
             }],
             duration: Duration::from_millis(230),
             success: true,
@@ -155,7 +156,7 @@ HTTP/1.0 200
         let doc = XmlDocument::new(element);
         assert_eq!(
             doc.to_string().unwrap(),
-            r#"<?xml version="1.0" encoding="utf-8"?><testcase id="test.hurl" name="test.hurl" time="0.230"><failure>Assert status code
+            r#"<?xml version="1.0" encoding="UTF-8"?><testcase id="test.hurl" name="test.hurl" time="0.230"><failure>Assert status code
   --&gt; test.hurl:2:10
    |
    | GET http://localhost:8000/not_found
@@ -186,6 +187,7 @@ HTTP/1.0 200
                 )],
                 transfer_duration: Duration::from_millis(0),
                 compressed: false,
+                curl_cmd: CurlCmd::default(),
             }],
             duration: Duration::from_millis(230),
             success: true,
@@ -196,7 +198,7 @@ HTTP/1.0 200
         let doc = XmlDocument::new(element);
         assert_eq!(
             doc.to_string().unwrap(),
-            r#"<?xml version="1.0" encoding="utf-8"?><testcase id="test.hurl" name="test.hurl" time="0.230"><error>HTTP connection
+            r#"<?xml version="1.0" encoding="UTF-8"?><testcase id="test.hurl" name="test.hurl" time="0.230"><error>HTTP connection
   --&gt; test.hurl:1:5
    |
  1 | GET http://unknown
