@@ -20,34 +20,51 @@ use std::fs::File;
 use std::io::Write;
 use std::path::Path;
 
-use super::Testcase;
-use crate::report::Error;
+use regex::Regex;
 
-// https://testanything.org/tap-version-13-specification.html
+use super::Testcase;
+use crate::report::ReportError;
+
+/// See <https://testanything.org/tap-version-13-specification.html>
 const TAP_REPORT_VERSION_MARKER: &str = "TAP version 13";
 
 /// Creates/Append a Tap report from a list of `testcases`
-pub fn write_report(filename: &Path, new_testcases: &[Testcase]) -> Result<(), Error> {
-    let mut testcases = vec![];
+pub fn write_report(filename: &Path, testcases: &[Testcase]) -> Result<(), ReportError> {
+    let mut all_testcases = vec![];
 
     let existing_testcases = parse_tap_file(filename)?;
     for testcase in existing_testcases.iter() {
-        testcases.push(testcase);
+        all_testcases.push(testcase);
     }
-    for testcase in new_testcases {
-        testcases.push(testcase);
+    for testcase in testcases {
+        all_testcases.push(testcase);
     }
-    write_tap_file(filename, &testcases)
+    write_tap_file(filename, &all_testcases)
 }
 
 /// Creates a Tap from a list of `testcases`.
-fn write_tap_file(filename: &Path, testcases: &[&Testcase]) -> Result<(), Error> {
+fn write_tap_file(filename: &Path, testcases: &[&Testcase]) -> Result<(), ReportError> {
+    // We ensure that parent folder is created.
+    if let Some(parent) = filename.parent() {
+        match std::fs::create_dir_all(parent) {
+            Ok(_) => {}
+            Err(err) => {
+                return Err(ReportError::from_error(
+                    err,
+                    filename,
+                    "Issue writing TAP report",
+                ))
+            }
+        }
+    }
     let mut file = match File::create(filename) {
         Ok(f) => f,
         Err(e) => {
-            return Err(Error {
-                message: format!("Failed to produce TAP report: {e:?}"),
-            });
+            return Err(ReportError::from_error(
+                e,
+                filename,
+                "Issue writing TAP report",
+            ))
         }
     };
     let start = 1;
@@ -64,35 +81,34 @@ fn write_tap_file(filename: &Path, testcases: &[&Testcase]) -> Result<(), Error>
     }
     match file.write_all(s.as_bytes()) {
         Ok(_) => Ok(()),
-        Err(e) => Err(Error {
-            message: format!("Failed to write TAP report: {e:?}"),
-        }),
+        Err(e) => Err(ReportError::from_error(
+            e,
+            filename,
+            "Issue writing TAP report",
+        )),
     }
 }
 
 /// Parse Tap report file
-fn parse_tap_file(filename: &Path) -> Result<Vec<Testcase>, Error> {
-    if filename.exists() {
-        let s = match std::fs::read_to_string(filename) {
-            Ok(s) => s,
-            Err(why) => {
-                return Err(Error {
-                    message: format!(
-                        "Issue reading {} to string to {:?}",
-                        filename.display(),
-                        why
-                    ),
-                });
-            }
-        };
-        parse_tap_report(&s)
-    } else {
-        Ok(vec![])
+fn parse_tap_file(filename: &Path) -> Result<Vec<Testcase>, ReportError> {
+    if !filename.exists() {
+        return Ok(vec![]);
     }
+    let s = match std::fs::read_to_string(filename) {
+        Ok(s) => s,
+        Err(e) => {
+            return Err(ReportError::from_error(
+                e,
+                filename,
+                "Issue reading TAP report",
+            ))
+        }
+    };
+    parse_tap_report(&s)
 }
 
 /// Parse Tap report
-fn parse_tap_report(s: &str) -> Result<Vec<Testcase>, Error> {
+fn parse_tap_report(s: &str) -> Result<Vec<Testcase>, ReportError> {
     let mut testcases = vec![];
     let mut lines: Vec<&str> = s.lines().collect::<Vec<&str>>();
     if !lines.is_empty() {
@@ -101,38 +117,12 @@ fn parse_tap_report(s: &str) -> Result<Vec<Testcase>, Error> {
         if header.eq_ignore_ascii_case(TAP_REPORT_VERSION_MARKER) {
             header = lines.remove(0);
         }
-
-        let header_tokens = header.split("..").collect::<Vec<&str>>();
-        match header_tokens.first() {
-            None => {
-                return Err(Error {
-                    message: format!("Invalid TAP Header <{header}>"),
-                });
-            }
-            Some(value) => match value.parse::<usize>() {
-                Ok(value) => value,
-                Err(_) => {
-                    return Err(Error {
-                        message: format!("Invalid TAP Header <{header}>"),
-                    })
-                }
-            },
-        };
-        match header_tokens.get(1) {
-            None => {
-                return Err(Error {
-                    message: format!("Invalid TAP Header <{header}>"),
-                });
-            }
-            Some(value) => match value.parse::<usize>() {
-                Ok(value) => value,
-                Err(_) => {
-                    return Err(Error {
-                        message: format!("Invalid TAP Header <{header}>"),
-                    })
-                }
-            },
-        };
+        let re = Regex::new(r"^1\.\.\d+.*$").unwrap();
+        if !re.is_match(header) {
+            return Err(ReportError::from_string(&format!(
+                "Invalid TAP Header <{header}>"
+            )));
+        }
         for line in lines {
             let line = line.trim();
             if !line.is_empty() {
@@ -201,5 +191,49 @@ not ok 3 - tests_ok/test.3.hurl
                 }
             ]
         );
+
+        let s = r#"TAP version 13
+1..5 # TAP header can have comments
+ok 1 - test.1.hurl
+ok 2 - test.2.hurl
+not ok 3 - test.3.hurl
+not ok 4 - test.4.hurl
+ok 5 - test.5.hurl
+"#;
+        assert_eq!(
+            parse_tap_report(s).unwrap(),
+            vec![
+                Testcase {
+                    description: "test.1.hurl".to_string(),
+                    success: true
+                },
+                Testcase {
+                    description: "test.2.hurl".to_string(),
+                    success: true
+                },
+                Testcase {
+                    description: "test.3.hurl".to_string(),
+                    success: false
+                },
+                Testcase {
+                    description: "test.4.hurl".to_string(),
+                    success: false
+                },
+                Testcase {
+                    description: "test.5.hurl".to_string(),
+                    success: true
+                }
+            ]
+        );
+    }
+
+    #[test]
+    fn test_parse_error() {
+        let s = r#"Dummy header
+ok 1 - test.1.hurl
+ok 2 - test.2.hurl
+not ok 3 - test.3.hurl
+"#;
+        assert!(parse_tap_report(s).is_err());
     }
 }
