@@ -15,18 +15,15 @@
  * limitations under the License.
  *
  */
-use std::collections::HashMap;
-
-use hurl_core::ast::*;
+use hurl_core::ast::{Entry, SourceInfo};
 
 use crate::http;
-use crate::http::ClientOptions;
+use crate::http::{ClientOptions, CurlCmd};
 use crate::runner::cache::BodyCache;
 use crate::runner::error::RunnerError;
 use crate::runner::result::{AssertResult, EntryResult};
 use crate::runner::runner_options::RunnerOptions;
-use crate::runner::value::Value;
-use crate::runner::{request, response, CaptureResult, RunnerErrorKind};
+use crate::runner::{request, response, CaptureResult, RunnerErrorKind, VariableSet};
 use crate::util::logger::{Logger, Verbosity};
 
 /// Runs an `entry` with `http_client` and returns one [`EntryResult`].
@@ -39,7 +36,7 @@ pub fn run(
     entry: &Entry,
     entry_index: usize,
     http_client: &mut http::Client,
-    variables: &mut HashMap<String, Value>,
+    variables: &mut VariableSet,
     runner_options: &RunnerOptions,
     logger: &mut Logger,
 ) -> EntryResult {
@@ -75,14 +72,15 @@ pub fn run(
         http_client.clear_cookie_storage(&client_options);
     }
 
-    log_request(
-        http_client,
+    let curl_cmd = http_client.curl_command_line(
         &http_request,
-        runner_options,
+        context_dir,
+        runner_options.output.as_ref(),
         &client_options,
-        logger,
     );
 
+    log_request(http_client, &curl_cmd, &http_request, logger);
+
     // Run the HTTP requests (optionally follow redirection)
     let calls = match http_client.execute_with_redirect(&http_request, &client_options, logger) {
         Ok(calls) => calls,
@@ -97,6 +95,7 @@ pub fn run(
                 source_info,
                 errors: vec![error],
                 compressed,
+                curl_cmd,
                 ..Default::default()
             };
         }
@@ -133,6 +132,7 @@ pub fn run(
                     errors,
                     transfer_duration,
                     compressed,
+                    curl_cmd,
                 };
             }
         }
@@ -153,6 +153,7 @@ pub fn run(
                         errors: vec![e],
                         transfer_duration,
                         compressed,
+                        curl_cmd,
                     };
                 }
             }
@@ -186,6 +187,7 @@ pub fn run(
         errors,
         transfer_duration,
         compressed,
+        curl_cmd,
     }
 }
 
@@ -220,7 +222,9 @@ impl ClientOptions {
             http_version: runner_options.http_version,
             ip_resolve: runner_options.ip_resolve,
             max_filesize: runner_options.max_filesize,
+            max_recv_speed: runner_options.max_recv_speed,
             max_redirect: runner_options.max_redirect,
+            max_send_speed: runner_options.max_send_speed,
             netrc: runner_options.netrc,
             netrc_file: runner_options.netrc_file.clone(),
             netrc_optional: runner_options.netrc_optional,
@@ -246,9 +250,8 @@ impl ClientOptions {
 /// Logs this HTTP `request`.
 fn log_request(
     http_client: &mut http::Client,
+    curl_cmd: &CurlCmd,
     request: &http::RequestSpec,
-    runner_options: &RunnerOptions,
-    client_options: &ClientOptions,
     logger: &mut Logger,
 ) {
     logger.debug("");
@@ -259,7 +262,7 @@ fn log_request(
 
     logger.debug("");
     logger.debug_important("Request:");
-    logger.debug(&format!("{} {}", request.method, request.url));
+    logger.debug(&format!("{} {}", request.method, request.url.raw()));
     for header in &request.headers {
         logger.debug(&header.to_string());
     }
@@ -289,11 +292,7 @@ fn log_request(
     }
     logger.debug("");
     logger.debug("Request can be run with the following curl command:");
-    let context_dir = &runner_options.context_dir;
-    let output = &runner_options.output;
-    let curl_command =
-        http_client.curl_command_line(request, context_dir, output.as_ref(), client_options);
-    logger.debug(&curl_command);
+    logger.debug(&curl_cmd.to_string());
     logger.debug("");
 }
 
