@@ -71,6 +71,10 @@ pub enum RunnerErrorKind {
     AssertVersion {
         actual: String,
     },
+    ExpressionInvalidType {
+        value: String,
+        expecting: String,
+    },
     /// I/O read error on `path`.
     FileReadAccess {
         path: PathBuf,
@@ -89,6 +93,10 @@ pub enum RunnerErrorKind {
         value: String,
     },
     InvalidRegex,
+    InvalidUrl {
+        url: String,
+        message: String,
+    },
     NoQueryResult,
     QueryHeaderNotFound,
     QueryInvalidJsonpathExpression {
@@ -97,16 +105,13 @@ pub enum RunnerErrorKind {
     QueryInvalidXpathEval,
     QueryInvalidXml,
     QueryInvalidJson,
+    ReadOnlySecret {
+        name: String,
+    },
     TemplateVariableNotDefined {
         name: String,
     },
-    TemplateVariableInvalidType {
-        name: String,
-        value: String,
-        expecting: String,
-    },
-    UnrenderableVariable {
-        name: String,
+    UnrenderableExpression {
         value: String,
     },
     /// Unauthorized file access, check `--file-root` option.
@@ -129,7 +134,7 @@ impl DisplaySourceError for RunnerError {
             RunnerErrorKind::AssertHeaderValueError { .. } => "Assert header value".to_string(),
             RunnerErrorKind::AssertStatus { .. } => "Assert status code".to_string(),
             RunnerErrorKind::AssertVersion { .. } => "Assert HTTP version".to_string(),
-
+            RunnerErrorKind::ExpressionInvalidType { .. } => "Invalid expression type".to_string(),
             RunnerErrorKind::FileReadAccess { .. } => "File read access".to_string(),
             RunnerErrorKind::FileWriteAccess { .. } => "File write access".to_string(),
             RunnerErrorKind::FilterDecode { .. } => "Filter error".to_string(),
@@ -138,6 +143,7 @@ impl DisplaySourceError for RunnerError {
             RunnerErrorKind::FilterMissingInput => "Filter error".to_string(),
             RunnerErrorKind::Http(http_error) => http_error.description(),
             RunnerErrorKind::InvalidJson { .. } => "Invalid JSON".to_string(),
+            RunnerErrorKind::InvalidUrl { .. } => "Invalid URL".to_string(),
             RunnerErrorKind::InvalidRegex => "Invalid regex".to_string(),
             RunnerErrorKind::NoQueryResult => "No query result".to_string(),
             RunnerErrorKind::QueryHeaderNotFound => "Header not found".to_string(),
@@ -147,14 +153,12 @@ impl DisplaySourceError for RunnerError {
             }
             RunnerErrorKind::QueryInvalidXml => "Invalid XML".to_string(),
             RunnerErrorKind::QueryInvalidXpathEval => "Invalid XPath expression".to_string(),
-            RunnerErrorKind::TemplateVariableInvalidType { .. } => {
-                "Invalid variable type".to_string()
-            }
+            RunnerErrorKind::ReadOnlySecret { .. } => "Readonly secret".to_string(),
             RunnerErrorKind::TemplateVariableNotDefined { .. } => "Undefined variable".to_string(),
             RunnerErrorKind::UnauthorizedFileAccess { .. } => {
                 "Unauthorized file access".to_string()
             }
-            RunnerErrorKind::UnrenderableVariable { .. } => "Unrenderable variable".to_string(),
+            RunnerErrorKind::UnrenderableExpression { .. } => "Unrenderable expression".to_string(),
         }
     }
 
@@ -203,7 +207,13 @@ impl DisplaySourceError for RunnerError {
                 let message = error::add_carets(message, self.source_info, content);
                 color_red_multiline_string(&message)
             }
-
+            RunnerErrorKind::ExpressionInvalidType {
+                value, expecting, ..
+            } => {
+                let message = &format!("expecting {expecting}, actual value is {value}");
+                let message = error::add_carets(message, self.source_info, content);
+                color_red_multiline_string(&message)
+            }
             RunnerErrorKind::FileReadAccess { path } => {
                 let message = &format!("file {} can not be read", path.to_string_lossy());
                 let message = error::add_carets(message, self.source_info, content);
@@ -244,6 +254,11 @@ impl DisplaySourceError for RunnerError {
                 let message = error::add_carets(message, self.source_info, content);
                 color_red_multiline_string(&message)
             }
+            RunnerErrorKind::InvalidUrl { url, message } => {
+                let message = &format!("invalid URL <{url}> ({message})");
+                let message = error::add_carets(message, self.source_info, content);
+                color_red_multiline_string(&message)
+            }
             RunnerErrorKind::InvalidRegex => {
                 let message = "regex expression is not valid";
                 let message = error::add_carets(message, self.source_info, content);
@@ -279,10 +294,8 @@ impl DisplaySourceError for RunnerError {
                 let message = error::add_carets(message, self.source_info, content);
                 color_red_multiline_string(&message)
             }
-            RunnerErrorKind::TemplateVariableInvalidType {
-                value, expecting, ..
-            } => {
-                let message = &format!("expecting {expecting}, actual value is {value}");
+            RunnerErrorKind::ReadOnlySecret { name } => {
+                let message = &format!("secret '{name}' can't be reassigned");
                 let message = error::add_carets(message, self.source_info, content);
                 color_red_multiline_string(&message)
             }
@@ -299,8 +312,8 @@ impl DisplaySourceError for RunnerError {
                 let message = error::add_carets(message, self.source_info, content);
                 color_red_multiline_string(&message)
             }
-            RunnerErrorKind::UnrenderableVariable { name, value } => {
-                let message = &format!("variable <{name}> with value {value} can not be rendered");
+            RunnerErrorKind::UnrenderableExpression { value } => {
+                let message = &format!("expression with value {value} can not be rendered");
                 let message = error::add_carets(message, self.source_info, content);
                 color_red_multiline_string(&message)
             }
