@@ -15,11 +15,9 @@
  * limitations under the License.
  *
  */
-use crate::util::term::Stderr;
-
 /// This trait is implemented by run event observers, during the execution of one Hurl file.
 pub trait EventListener {
     /// Call when running an entry, `entry_index` is the entry 0-based index in the Hurl file,
     /// and `entry_count` is the total number of entries in the Hurl file.
-    fn on_running(&self, entry_index: usize, entry_count: usize, stderr: &mut Stderr);
+    fn on_running(&self, entry_index: usize, entry_count: usize);
 }
