@@ -15,22 +15,21 @@
  * limitations under the License.
  *
  */
-use std::collections::HashMap;
-
-use hurl_core::ast::{JsonListElement, JsonObjectElement, JsonValue, Template, TemplateElement};
+use hurl_core::ast::{
+    JsonListElement, JsonObjectElement, JsonValue, Placeholder, Template, TemplateElement,
+};
 use hurl_core::parser::{parse_json_boolean, parse_json_null, parse_json_number};
 use hurl_core::reader::Reader;
 
 use crate::runner::error::{RunnerError, RunnerErrorKind};
-use crate::runner::template::render_expression;
-use crate::runner::value::Value;
+use crate::runner::{expr, VariableSet};
 
 /// Evaluates a JSON value to a string given a set of `variables`.
 /// If `keep_whitespace` is true, whitespace is preserved from the JSonValue, otherwise
 /// it is trimmed.
 pub fn eval_json_value(
     json_value: &JsonValue,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
     keep_whitespace: bool,
 ) -> Result<String, RunnerError> {
     match json_value {
@@ -65,8 +64,8 @@ pub fn eval_json_value(
                 Ok(format!("{{{}}}", elems_string.join(",")))
             }
         }
-        JsonValue::Expression(exp) => {
-            let s = render_expression(exp, variables)?;
+        JsonValue::Placeholder(Placeholder { expr, .. }) => {
+            let s = expr::render(expr, variables)?;
 
             // The String can only be null, a bool, a number
             // It will be easier when your variables value have a type
@@ -84,7 +83,7 @@ pub fn eval_json_value(
                 return Ok(s);
             }
             let kind = RunnerErrorKind::InvalidJson { value: s };
-            Err(RunnerError::new(exp.variable.source_info, kind, false))
+            Err(RunnerError::new(expr.source_info, kind, false))
         }
     }
 }
@@ -94,7 +93,7 @@ pub fn eval_json_value(
 /// it is trimmed.
 fn eval_json_list_element(
     element: &JsonListElement,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
     keep_whitespace: bool,
 ) -> Result<String, RunnerError> {
     let s = eval_json_value(&element.value, variables, keep_whitespace)?;
@@ -110,7 +109,7 @@ fn eval_json_list_element(
 /// it is trimmed.
 fn eval_json_object_element(
     element: &JsonObjectElement,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
     keep_whitespace: bool,
 ) -> Result<String, RunnerError> {
     let value = eval_json_value(&element.value, variables, keep_whitespace)?;
@@ -132,7 +131,7 @@ fn eval_json_object_element(
 /// will be evaluated to the JSON String "Hello \""
 pub fn eval_json_template(
     template: &Template,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
 ) -> Result<String, RunnerError> {
     let Template { elements, .. } = template;
     {
@@ -149,12 +148,12 @@ pub fn eval_json_template(
 
 fn eval_json_template_element(
     template_element: &TemplateElement,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
 ) -> Result<String, RunnerError> {
     match template_element {
         TemplateElement::String { encoded, .. } => Ok(encoded.clone()),
-        TemplateElement::Expression(expr) => {
-            let s = render_expression(expr, variables)?;
+        TemplateElement::Placeholder(Placeholder { expr, .. }) => {
+            let s = expr::render(expr, variables)?;
             Ok(encode_json_string(&s))
         }
     }
@@ -177,6 +176,7 @@ fn encode_json_char(c: char) -> String {
 
 #[cfg(test)]
 mod tests {
+    use crate::runner::Value;
     use hurl_core::ast::*;
     use hurl_core::reader::Pos;
 
@@ -192,13 +192,16 @@ mod tests {
                     value: "Hello ".to_string(),
                     encoded: "Hello\\u0020".to_string(),
                 },
-                TemplateElement::Expression(Expr {
+                TemplateElement::Placeholder(Placeholder {
                     space0: Whitespace {
                         value: String::new(),
                         source_info: SourceInfo::new(Pos::new(1, 15), Pos::new(1, 15)),
                     },
-                    variable: Variable {
-                        name: "name".to_string(),
+                    expr: Expr {
+                        kind: ExprKind::Variable(Variable {
+                            name: "name".to_string(),
+                            source_info: SourceInfo::new(Pos::new(1, 15), Pos::new(1, 19)),
+                        }),
                         source_info: SourceInfo::new(Pos::new(1, 15), Pos::new(1, 19)),
                     },
                     space1: Whitespace {
@@ -245,8 +248,10 @@ mod tests {
 
     #[test]
     fn test_scalar_value() {
-        let mut variables = HashMap::new();
-        variables.insert("name".to_string(), Value::String("Bob".to_string()));
+        let mut variables = VariableSet::new();
+        variables
+            .insert("name".to_string(), Value::String("Bob".to_string()))
+            .unwrap();
         assert_eq!(
             eval_json_value(&JsonValue::Null, &variables, true).unwrap(),
             "null".to_string()
@@ -267,7 +272,7 @@ mod tests {
 
     #[test]
     fn test_error() {
-        let variables = HashMap::new();
+        let variables = VariableSet::new();
         let error = eval_json_value(&json_hello_world_value(), &variables, true)
             .err()
             .unwrap();
@@ -285,8 +290,10 @@ mod tests {
 
     #[test]
     fn test_list_value() {
-        let mut variables = HashMap::new();
-        variables.insert("name".to_string(), Value::String("Bob".to_string()));
+        let mut variables = VariableSet::new();
+        variables
+            .insert("name".to_string(), Value::String("Bob".to_string()))
+            .unwrap();
         assert_eq!(
             eval_json_value(
                 &JsonValue::List {
@@ -364,7 +371,7 @@ mod tests {
 
     #[test]
     fn test_object_value() {
-        let variables = HashMap::new();
+        let variables = VariableSet::new();
         assert_eq!(
             eval_json_value(
                 &JsonValue::Object {
@@ -388,7 +395,7 @@ mod tests {
 
     #[test]
     fn test_escape_sequence() {
-        let variables = HashMap::new();
+        let variables = VariableSet::new();
         assert_eq!(
             eval_json_value(
                 &JsonValue::String(Template {
@@ -409,7 +416,7 @@ mod tests {
 
     #[test]
     fn test_eval_json_template() {
-        let variables = HashMap::new();
+        let variables = VariableSet::new();
         assert_eq!(
             eval_json_template(
                 &Template {
@@ -426,8 +433,10 @@ mod tests {
             "\\n".to_string()
         );
 
-        let mut variables = HashMap::new();
-        variables.insert("quote".to_string(), Value::String("\"".to_string()));
+        let mut variables = VariableSet::new();
+        variables
+            .insert("quote".to_string(), Value::String("\"".to_string()))
+            .unwrap();
         assert_eq!(
             eval_json_template(
                 &Template {
@@ -437,10 +446,13 @@ mod tests {
                             value: "Hello ".to_string(),
                             encoded: "Hello ".to_string(),
                         },
-                        TemplateElement::Expression(Expr {
+                        TemplateElement::Placeholder(Placeholder {
                             space0: whitespace(),
-                            variable: Variable {
-                                name: "quote".to_string(),
+                            expr: Expr {
+                                kind: ExprKind::Variable(Variable {
+                                    name: "quote".to_string(),
+                                    source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                                }),
                                 source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
                             },
                             space1: whitespace(),
@@ -471,7 +483,7 @@ mod tests {
 
     #[test]
     fn test_not_preserving_spaces() {
-        let variables = HashMap::new();
+        let variables = VariableSet::new();
         assert_eq!(
             eval_json_value(&json_person_value(), &variables, false).unwrap(),
             r#"{"firstName":"John"}"#.to_string()
