@@ -15,17 +15,17 @@
  * limitations under the License.
  *
  */
-use std::collections::HashMap;
-
 use hurl_core::ast::{
-    BooleanOption, CountOption, DurationOption, Entry, EntryOption, Float, Number as AstNumber,
-    OptionKind, SectionValue, VariableDefinition, VariableValue,
+    BooleanOption, CountOption, DurationOption, Entry, EntryOption, Float, NaturalOption,
+    Number as AstNumber, OptionKind, Placeholder, SectionValue, VariableDefinition, VariableValue,
 };
-use hurl_core::typing::{Count, DurationUnit};
+use hurl_core::typing::{BytesPerSec, Count, DurationUnit};
 
 use crate::http::{IpResolve, RequestedHttpVersion};
-use crate::runner::template::{eval_expression, eval_template};
-use crate::runner::{Number, Output, RunnerError, RunnerErrorKind, RunnerOptions, Value};
+use crate::runner::template::eval_template;
+use crate::runner::{
+    expr, Number, Output, RunnerError, RunnerErrorKind, RunnerOptions, Value, VariableSet,
+};
 use crate::util::logger::{Logger, Verbosity};
 
 /// Returns a new [`RunnerOptions`] based on the `entry` optional Options section
@@ -34,7 +34,7 @@ use crate::util::logger::{Logger, Verbosity};
 pub fn get_entry_options(
     entry: &Entry,
     runner_options: &RunnerOptions,
-    variables: &mut HashMap<String, Value>,
+    variables: &mut VariableSet,
     logger: &mut Logger,
 ) -> Result<RunnerOptions, RunnerError> {
     let runner_options = runner_options.clone();
@@ -80,6 +80,11 @@ pub fn get_entry_options(
                         let value = eval_template(value, variables)?;
                         entry_options.connects_to.push(value);
                     }
+                    OptionKind::ConnectTimeout(value) => {
+                        let value =
+                            eval_duration_option(value, variables, DurationUnit::MilliSecond)?;
+                        entry_options.connect_timeout = value;
+                    }
                     OptionKind::Delay(value) => {
                         let value =
                             eval_duration_option(value, variables, DurationUnit::MilliSecond)?;
@@ -170,6 +175,11 @@ pub fn get_entry_options(
                             IpResolve::IpV4
                         }
                     }
+                    OptionKind::LimitRate(value) => {
+                        let value = eval_natural_option(value, variables)?;
+                        entry_options.max_send_speed = Some(BytesPerSec(value));
+                        entry_options.max_recv_speed = Some(BytesPerSec(value));
+                    }
                     OptionKind::MaxRedirect(value) => {
                         let value = eval_count_option(value, variables)?;
                         entry_options.max_redirect = value;
@@ -228,9 +238,16 @@ pub fn get_entry_options(
                         let value = eval_template(value, variables)?;
                         entry_options.user = Some(value);
                     }
-                    OptionKind::Variable(VariableDefinition { name, value, .. }) => {
+                    OptionKind::Variable(VariableDefinition {
+                        source_info,
+                        name,
+                        value,
+                        ..
+                    }) => {
                         let value = eval_variable_value(value, variables)?;
-                        variables.insert(name.clone(), value);
+                        if let Err(err) = variables.insert(name.clone(), value) {
+                            return Err(err.to_runner_error(*source_info));
+                        }
                     }
                     // verbose and very-verbose option have been previously processed as they
                     // can impact the logging. We compute here their values to check the potential
@@ -269,7 +286,7 @@ fn has_options(entry: &Entry) -> bool {
 pub fn get_entry_verbosity(
     entry: &Entry,
     default_verbosity: Option<Verbosity>,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
 ) -> Result<Option<Verbosity>, RunnerError> {
     let mut verbosity = default_verbosity;
 
@@ -303,52 +320,82 @@ pub fn get_entry_verbosity(
 
 fn eval_boolean_option(
     boolean_value: &BooleanOption,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
 ) -> Result<bool, RunnerError> {
     match boolean_value {
         BooleanOption::Literal(value) => Ok(*value),
-        BooleanOption::Expression(expr) => match eval_expression(expr, variables)? {
-            Value::Bool(value) => Ok(value),
-            v => {
-                let kind = RunnerErrorKind::TemplateVariableInvalidType {
-                    name: expr.variable.name.clone(),
-                    value: v.format(),
-                    expecting: "boolean".to_string(),
-                };
-                Err(RunnerError::new(expr.variable.source_info, kind, false))
+        BooleanOption::Placeholder(Placeholder { expr, .. }) => {
+            match expr::eval(expr, variables)? {
+                Value::Bool(value) => Ok(value),
+                v => {
+                    let kind = RunnerErrorKind::ExpressionInvalidType {
+                        value: v.format(),
+                        expecting: "boolean".to_string(),
+                    };
+                    Err(RunnerError::new(expr.source_info, kind, false))
+                }
             }
-        },
+        }
+    }
+}
+
+fn eval_natural_option(
+    natural_value: &NaturalOption,
+    variables: &VariableSet,
+) -> Result<u64, RunnerError> {
+    match natural_value {
+        NaturalOption::Literal(value) => Ok(*value),
+        NaturalOption::Placeholder(Placeholder { expr, .. }) => {
+            match expr::eval(expr, variables)? {
+                Value::Number(Number::Integer(value)) => {
+                    if value > 0 {
+                        Ok(value as u64)
+                    } else {
+                        let kind = RunnerErrorKind::ExpressionInvalidType {
+                            value: format!("integer <{value}>"),
+                            expecting: "integer > 0".to_string(),
+                        };
+                        Err(RunnerError::new(expr.source_info, kind, false))
+                    }
+                }
+                v => {
+                    let kind = RunnerErrorKind::ExpressionInvalidType {
+                        value: v.format(),
+                        expecting: "integer".to_string(),
+                    };
+                    Err(RunnerError::new(expr.source_info, kind, false))
+                }
+            }
+        }
     }
 }
 
 fn eval_count_option(
     count_value: &CountOption,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
 ) -> Result<Count, RunnerError> {
     match count_value {
         CountOption::Literal(repeat) => Ok(*repeat),
-        CountOption::Expression(expr) => match eval_expression(expr, variables)? {
+        CountOption::Placeholder(Placeholder { expr, .. }) => match expr::eval(expr, variables)? {
             Value::Number(Number::Integer(value)) => {
                 if value == -1 {
                     Ok(Count::Infinite)
                 } else if value >= 0 {
                     Ok(Count::Finite(value as usize))
                 } else {
-                    let kind = RunnerErrorKind::TemplateVariableInvalidType {
-                        name: expr.variable.name.clone(),
+                    let kind = RunnerErrorKind::ExpressionInvalidType {
                         value: format!("integer <{value}>"),
                         expecting: "integer >= -1".to_string(),
                     };
-                    Err(RunnerError::new(expr.variable.source_info, kind, false))
+                    Err(RunnerError::new(expr.source_info, kind, false))
                 }
             }
             v => {
-                let kind = RunnerErrorKind::TemplateVariableInvalidType {
-                    name: expr.variable.name.clone(),
+                let kind = RunnerErrorKind::ExpressionInvalidType {
                     value: v.format(),
                     expecting: "integer".to_string(),
                 };
-                Err(RunnerError::new(expr.variable.source_info, kind, false))
+                Err(RunnerError::new(expr.source_info, kind, false))
             }
         },
     }
@@ -357,7 +404,7 @@ fn eval_count_option(
 /// return duration value in milliseconds
 fn eval_duration_option(
     duration_value: &DurationOption,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
     default_unit: DurationUnit,
 ) -> Result<std::time::Duration, RunnerError> {
     let millis = match duration_value {
@@ -370,15 +417,15 @@ fn eval_duration_option(
                 DurationUnit::Minute => value.value * 1000 * 60,
             }
         }
-        DurationOption::Expression(expr) => match eval_expression(expr, variables)? {
+        DurationOption::Placeholder(Placeholder { expr, .. }) => match expr::eval(expr, variables)?
+        {
             Value::Number(Number::Integer(value)) => {
                 if value < 0 {
-                    let kind = RunnerErrorKind::TemplateVariableInvalidType {
-                        name: expr.variable.name.clone(),
+                    let kind = RunnerErrorKind::ExpressionInvalidType {
                         value: format!("integer <{value}>"),
                         expecting: "positive integer".to_string(),
                     };
-                    return Err(RunnerError::new(expr.variable.source_info, kind, false));
+                    return Err(RunnerError::new(expr.source_info, kind, false));
                 } else {
                     match default_unit {
                         DurationUnit::MilliSecond => value as u64,
@@ -388,12 +435,11 @@ fn eval_duration_option(
                 }
             }
             v => {
-                let kind = RunnerErrorKind::TemplateVariableInvalidType {
-                    name: expr.variable.name.clone(),
+                let kind = RunnerErrorKind::ExpressionInvalidType {
                     value: v.format(),
                     expecting: "positive integer".to_string(),
                 };
-                return Err(RunnerError::new(expr.variable.source_info, kind, false));
+                return Err(RunnerError::new(expr.source_info, kind, false));
             }
         },
     };
@@ -402,7 +448,7 @@ fn eval_duration_option(
 
 fn eval_variable_value(
     variable_value: &VariableValue,
-    variables: &mut HashMap<String, Value>,
+    variables: &mut VariableSet,
 ) -> Result<Value, RunnerError> {
     match variable_value {
         VariableValue::Null => Ok(Value::Null),
@@ -425,7 +471,7 @@ fn eval_number(number: &AstNumber) -> Value {
 
 #[cfg(test)]
 mod tests {
-    use hurl_core::ast::{Expr, SourceInfo, Variable, Whitespace};
+    use hurl_core::ast::{Expr, ExprKind, Placeholder, SourceInfo, Variable, Whitespace};
     use hurl_core::reader::Pos;
     use hurl_core::typing::{Duration, DurationUnit};
 
@@ -434,13 +480,16 @@ mod tests {
 
     fn verbose_option_template() -> BooleanOption {
         // {{verbose}}
-        BooleanOption::Expression(Expr {
+        BooleanOption::Placeholder(Placeholder {
             space0: Whitespace {
                 value: String::new(),
                 source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
             },
-            variable: Variable {
-                name: "verbose".to_string(),
+            expr: Expr {
+                kind: ExprKind::Variable(Variable {
+                    name: "verbose".to_string(),
+                    source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                }),
                 source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
             },
             space1: Whitespace {
@@ -452,13 +501,16 @@ mod tests {
 
     fn retry_option_template() -> DurationOption {
         // {{retry}}
-        DurationOption::Expression(Expr {
+        DurationOption::Placeholder(Placeholder {
             space0: Whitespace {
                 value: String::new(),
                 source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
             },
-            variable: Variable {
-                name: "retry".to_string(),
+            expr: Expr {
+                kind: ExprKind::Variable(Variable {
+                    name: "retry".to_string(),
+                    source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                }),
                 source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
             },
             space1: Whitespace {
@@ -470,16 +522,18 @@ mod tests {
 
     #[test]
     fn test_eval_boolean_option() {
-        let mut variables = HashMap::default();
+        let mut variables = VariableSet::default();
         assert!(eval_boolean_option(&BooleanOption::Literal(true), &variables).unwrap());
 
-        variables.insert("verbose".to_string(), Value::Bool(true));
+        variables
+            .insert("verbose".to_string(), Value::Bool(true))
+            .unwrap();
         assert!(eval_boolean_option(&verbose_option_template(), &variables).unwrap());
     }
 
     #[test]
     fn test_eval_boolean_option_error() {
-        let mut variables = HashMap::default();
+        let mut variables = VariableSet::default();
         let error = eval_boolean_option(&verbose_option_template(), &variables)
             .err()
             .unwrap();
@@ -491,14 +545,15 @@ mod tests {
             }
         );
 
-        variables.insert("verbose".to_string(), Value::Number(Number::Integer(10)));
+        variables
+            .insert("verbose".to_string(), Value::Number(Number::Integer(10)))
+            .unwrap();
         let error = eval_boolean_option(&verbose_option_template(), &variables)
             .err()
             .unwrap();
         assert_eq!(
             error.kind,
-            RunnerErrorKind::TemplateVariableInvalidType {
-                name: "verbose".to_string(),
+            RunnerErrorKind::ExpressionInvalidType {
                 value: "integer <10>".to_string(),
                 expecting: "boolean".to_string()
             }
@@ -507,7 +562,7 @@ mod tests {
 
     #[test]
     fn test_eval_natural_option() {
-        let mut variables = HashMap::default();
+        let mut variables = VariableSet::default();
         assert_eq!(
             eval_duration_option(
                 &DurationOption::Literal(Duration::new(1, Some(DurationUnit::Second))),
@@ -518,7 +573,9 @@ mod tests {
             std::time::Duration::from_millis(1000)
         );
 
-        variables.insert("retry".to_string(), Value::Number(Number::Integer(10)));
+        variables
+            .insert("retry".to_string(), Value::Number(Number::Integer(10)))
+            .unwrap();
         assert_eq!(
             eval_duration_option(
                 &retry_option_template(),
