@@ -15,21 +15,19 @@
  * limitations under the License.
  *
  */
-use std::collections::HashMap;
-
-use hurl_core::ast::*;
+use hurl_core::ast::{Number, Placeholder, PredicateValue};
 
 use crate::runner::body::eval_file; // TODO move function out of body module
 use crate::runner::error::RunnerError;
-use crate::runner::expr::eval_expr;
+use crate::runner::expr::eval;
 use crate::runner::multiline::eval_multiline;
 use crate::runner::template::eval_template;
-use crate::runner::{Number as ValueNumber, Value};
+use crate::runner::{Number as ValueNumber, Value, VariableSet};
 use crate::util::path::ContextDir;
 
 pub fn eval_predicate_value(
     predicate_value: &PredicateValue,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
     context_dir: &ContextDir,
 ) -> Result<Value, RunnerError> {
     match predicate_value {
@@ -50,8 +48,8 @@ pub fn eval_predicate_value(
         }
         PredicateValue::Hex(value) => Ok(Value::Bytes(value.value.clone())),
         PredicateValue::Base64(value) => Ok(Value::Bytes(value.value.clone())),
-        PredicateValue::Expression(expr) => {
-            let value = eval_expr(expr, variables)?;
+        PredicateValue::Placeholder(Placeholder { expr, .. }) => {
+            let value = eval(expr, variables)?;
             Ok(value)
         }
         PredicateValue::Regex(regex) => Ok(Value::Regex(regex.inner.clone())),
@@ -60,7 +58,7 @@ pub fn eval_predicate_value(
 
 pub fn eval_predicate_value_template(
     predicate_value: &PredicateValue,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
 ) -> Result<String, RunnerError> {
     match predicate_value {
         PredicateValue::String(template) => eval_template(template, variables),
