@@ -15,27 +15,28 @@
  * limitations under the License.
  *
  */
-use std::collections::HashMap;
+use std::str::FromStr;
 
 use base64::engine::general_purpose;
 use base64::Engine;
-use hurl_core::ast::*;
+use hurl_core::ast::{
+    Body, Bytes, Method, MultilineString, MultilineStringKind, Request, Template,
+};
 
 use crate::http;
-use crate::http::{HeaderVec, AUTHORIZATION};
+use crate::http::{HeaderVec, HttpError, Url, AUTHORIZATION};
 use crate::runner::error::RunnerError;
-use crate::runner::value::Value;
-use crate::runner::{body, multipart, template};
+use crate::runner::{body, multipart, template, RunnerErrorKind, VariableSet};
 use crate::util::path::ContextDir;
 
 /// Transforms an AST `request` to a spec request given a set of `variables`.
 pub fn eval_request(
     request: &Request,
-    variables: &HashMap<String, Value>,
+    variables: &VariableSet,
     context_dir: &ContextDir,
 ) -> Result<http::RequestSpec, RunnerError> {
     let method = eval_method(&request.method);
-    let url = template::eval_template(&request.url, variables)?;
+    let url = eval_url(&request.url, variables)?;
 
     // Headers
     let mut headers = HeaderVec::new();
@@ -143,6 +144,20 @@ pub fn eval_request(
     })
 }
 
+fn eval_url(url_template: &Template, variables: &VariableSet) -> Result<Url, RunnerError> {
+    let url = template::eval_template(url_template, variables)?;
+    Url::from_str(&url).map_err(|e| {
+        let source_info = url_template.source_info;
+        let message = if let HttpError::InvalidUrl(_, message) = e {
+            message
+        } else {
+            String::new()
+        };
+        let runner_error_kind = RunnerErrorKind::InvalidUrl { url, message };
+        RunnerError::new(source_info, runner_error_kind, false)
+    })
+}
+
 /// Experimental feature
 /// @cookie_storage_add
 pub fn cookie_storage_set(request: &Request) -> Option<String> {
@@ -177,7 +192,11 @@ fn eval_method(method: &Method) -> http::Method {
 
 #[cfg(test)]
 mod tests {
-    use hurl_core::ast::SourceInfo;
+    use crate::runner::Value;
+    use hurl_core::ast::{
+        Comment, Expr, ExprKind, KeyValue, LineTerminator, Placeholder, Section, SectionValue,
+        SourceInfo, TemplateElement, Variable, Whitespace,
+    };
     use hurl_core::reader::Pos;
 
     use super::super::error::RunnerErrorKind;
@@ -203,10 +222,13 @@ mod tests {
             space1: whitespace(),
             url: Template {
                 elements: vec![
-                    TemplateElement::Expression(Expr {
+                    TemplateElement::Placeholder(Placeholder {
                         space0: whitespace(),
-                        variable: Variable {
-                            name: String::from("base_url"),
+                        expr: Expr {
+                            kind: ExprKind::Variable(Variable {
+                                name: "base_url".to_string(),
+                                source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 15)),
+                            }),
                             source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 15)),
                         },
                         space1: whitespace(),
@@ -269,48 +291,60 @@ mod tests {
                 line_terminators: vec![],
                 space0: whitespace(),
                 line_terminator0: line_terminator,
-                value: SectionValue::QueryParams(vec![
-                    simple_key_value(
-                        Template {
-                            delimiter: None,
-                            elements: vec![TemplateElement::String {
-                                value: "param1".to_string(),
-                                encoded: "param1".to_string(),
-                            }],
-                            source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
-                        },
-                        Template {
-                            delimiter: None,
-                            elements: vec![TemplateElement::Expression(Expr {
-                                space0: whitespace(),
-                                variable: Variable {
-                                    name: String::from("param1"),
-                                    source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 15)),
-                                },
-                                space1: whitespace(),
-                            })],
-                            source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
-                        },
-                    ),
-                    simple_key_value(
-                        Template {
-                            delimiter: None,
-                            elements: vec![TemplateElement::String {
-                                value: "param2".to_string(),
-                                encoded: "param2".to_string(),
-                            }],
-                            source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
-                        },
-                        Template {
-                            delimiter: None,
-                            elements: vec![TemplateElement::String {
-                                value: "a b".to_string(),
-                                encoded: "a b".to_string(),
-                            }],
-                            source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
-                        },
-                    ),
-                ]),
+                value: SectionValue::QueryParams(
+                    vec![
+                        simple_key_value(
+                            Template {
+                                delimiter: None,
+                                elements: vec![TemplateElement::String {
+                                    value: "param1".to_string(),
+                                    encoded: "param1".to_string(),
+                                }],
+                                source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                            },
+                            Template {
+                                delimiter: None,
+                                elements: vec![TemplateElement::Placeholder(Placeholder {
+                                    space0: whitespace(),
+                                    expr: Expr {
+                                        kind: ExprKind::Variable(Variable {
+                                            name: "param1".to_string(),
+                                            source_info: SourceInfo::new(
+                                                Pos::new(1, 7),
+                                                Pos::new(1, 15),
+                                            ),
+                                        }),
+                                        source_info: SourceInfo::new(
+                                            Pos::new(1, 7),
+                                            Pos::new(1, 15),
+                                        ),
+                                    },
+                                    space1: whitespace(),
+                                })],
+                                source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                            },
+                        ),
+                        simple_key_value(
+                            Template {
+                                delimiter: None,
+                                elements: vec![TemplateElement::String {
+                                    value: "param2".to_string(),
+                                    encoded: "param2".to_string(),
+                                }],
+                                source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                            },
+                            Template {
+                                delimiter: None,
+                                elements: vec![TemplateElement::String {
+                                    value: "a b".to_string(),
+                                    encoded: "a b".to_string(),
+                                }],
+                                source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                            },
+                        ),
+                    ],
+                    false,
+                ),
                 source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
             }],
             body: None,
@@ -320,7 +354,7 @@ mod tests {
 
     #[test]
     fn test_error_variable() {
-        let variables = HashMap::new();
+        let variables = VariableSet::new();
         let error = eval_request(&hello_request(), &variables, &ContextDir::default())
             .err()
             .unwrap();
@@ -338,11 +372,13 @@ mod tests {
 
     #[test]
     fn test_hello_request() {
-        let mut variables = HashMap::new();
-        variables.insert(
-            String::from("base_url"),
-            Value::String(String::from("http://localhost:8000")),
-        );
+        let mut variables = VariableSet::new();
+        variables
+            .insert(
+                String::from("base_url"),
+                Value::String(String::from("http://localhost:8000")),
+            )
+            .unwrap();
         let http_request =
             eval_request(&hello_request(), &variables, &ContextDir::default()).unwrap();
         assert_eq!(http_request, http::hello_http_request());
@@ -350,11 +386,13 @@ mod tests {
 
     #[test]
     fn test_query_request() {
-        let mut variables = HashMap::new();
-        variables.insert(
-            String::from("param1"),
-            Value::String(String::from("value1")),
-        );
+        let mut variables = VariableSet::new();
+        variables
+            .insert(
+                String::from("param1"),
+                Value::String(String::from("value1")),
+            )
+            .unwrap();
         let http_request =
             eval_request(&query_request(), &variables, &ContextDir::default()).unwrap();
         assert_eq!(http_request, http::query_http_request());
