@@ -58,7 +58,7 @@ pub struct Request {
 impl Request {
     pub fn querystring_params(&self) -> Vec<KeyValue> {
         for section in &self.sections {
-            if let SectionValue::QueryParams(params) = &section.value {
+            if let SectionValue::QueryParams(params, _) = &section.value {
                 return params.clone();
             }
         }
@@ -66,7 +66,7 @@ impl Request {
     }
     pub fn form_params(&self) -> Vec<KeyValue> {
         for section in &self.sections {
-            if let SectionValue::FormParams(params) = &section.value {
+            if let SectionValue::FormParams(params, _) = &section.value {
                 return params.clone();
             }
         }
@@ -74,7 +74,7 @@ impl Request {
     }
     pub fn multipart_form_data(&self) -> Vec<MultipartParam> {
         for section in &self.sections {
-            if let SectionValue::MultipartFormData(params) = &section.value {
+            if let SectionValue::MultipartFormData(params, _) = &section.value {
                 return params.clone();
             }
         }
@@ -203,12 +203,15 @@ impl Section {
     pub fn name(&self) -> &str {
         match self.value {
             SectionValue::Asserts(_) => "Asserts",
-            SectionValue::QueryParams(_) => "QueryStringParams",
+            SectionValue::QueryParams(_, true) => "Query",
+            SectionValue::QueryParams(_, false) => "QueryStringParams",
             SectionValue::BasicAuth(_) => "BasicAuth",
-            SectionValue::FormParams(_) => "FormParams",
+            SectionValue::FormParams(_, true) => "Form",
+            SectionValue::FormParams(_, false) => "FormParams",
             SectionValue::Cookies(_) => "Cookies",
             SectionValue::Captures(_) => "Captures",
-            SectionValue::MultipartFormData(_) => "MultipartFormData",
+            SectionValue::MultipartFormData(_, true) => "Multipart",
+            SectionValue::MultipartFormData(_, false) => "MultipartFormData",
             SectionValue::Options(_) => "Options",
         }
     }
@@ -217,10 +220,10 @@ impl Section {
 #[derive(Clone, Debug, PartialEq, Eq)]
 #[allow(clippy::large_enum_variant)]
 pub enum SectionValue {
-    QueryParams(Vec<KeyValue>),
-    BasicAuth(Option<KeyValue>),
-    FormParams(Vec<KeyValue>),
-    MultipartFormData(Vec<MultipartParam>),
+    QueryParams(Vec<KeyValue>, bool), // boolean param indicates if we use the short syntax
+    BasicAuth(Option<KeyValue>),      // boolean param indicates if we use the short syntax
+    FormParams(Vec<KeyValue>, bool),
+    MultipartFormData(Vec<MultipartParam>, bool), // boolean param indicates if we use the short syntax
     Cookies(Vec<Cookie>),
     Captures(Vec<Capture>),
     Asserts(Vec<Assert>),
@@ -423,12 +426,12 @@ pub struct PredicateFunc {
 pub enum PredicateValue {
     Base64(Base64),
     Bool(bool),
-    Expression(Expr),
     File(File),
     Hex(Hex),
     MultilineString(MultilineString),
     Null,
     Number(Number),
+    Placeholder(Placeholder),
     Regex(Regex),
     String(Template),
 }
@@ -507,6 +510,7 @@ pub struct MultilineString {
     pub attributes: Vec<MultilineStringAttribute>,
 }
 
+#[allow(clippy::large_enum_variant)]
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum MultilineStringKind {
     Text(Text),
@@ -589,7 +593,7 @@ pub struct Template {
 pub enum TemplateElement {
     // TODO: explain the difference between value and encoded
     String { value: String, encoded: String },
-    Expression(Expr),
+    Placeholder(Placeholder),
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -643,6 +647,7 @@ pub struct LineTerminator {
     pub newline: Whitespace,
 }
 
+#[allow(clippy::large_enum_variant)]
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum Bytes {
     Json(json::Value),
@@ -688,18 +693,42 @@ impl SourceInfo {
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
-pub struct Expr {
+pub struct Placeholder {
     pub space0: Whitespace,
-    pub variable: Variable,
+    pub expr: Expr,
     pub space1: Whitespace,
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct Expr {
+    pub source_info: SourceInfo,
+    pub kind: ExprKind,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum ExprKind {
+    Variable(Variable),
+    Function(Function),
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Variable {
     pub name: String,
     pub source_info: SourceInfo,
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum Function {
+    NewDate,
+    NewUuid,
+}
+
+/// Check that variable name is not reserved
+/// (would conflicts with an existing function)
+pub fn is_variable_reserved(name: &str) -> bool {
+    ["getEnv", "newDate", "newUuid"].contains(&name)
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct EntryOption {
     pub line_terminators: Vec<LineTerminator>,
@@ -718,6 +747,7 @@ pub enum OptionKind {
     ClientKey(Template),
     Compressed(BooleanOption),
     ConnectTo(Template),
+    ConnectTimeout(DurationOption),
     Delay(DurationOption),
     Http10(BooleanOption),
     Http11(BooleanOption),
@@ -728,6 +758,7 @@ pub enum OptionKind {
     IpV6(BooleanOption),
     FollowLocation(BooleanOption),
     FollowLocationTrusted(BooleanOption),
+    LimitRate(NaturalOption),
     MaxRedirect(CountOption),
     NetRc(BooleanOption),
     NetRcFile(Template),
@@ -756,6 +787,7 @@ impl OptionKind {
             OptionKind::ClientKey(_) => "key",
             OptionKind::Compressed(_) => "compressed",
             OptionKind::ConnectTo(_) => "connect-to",
+            OptionKind::ConnectTimeout(_) => "connect-timeout",
             OptionKind::Delay(_) => "delay",
             OptionKind::FollowLocation(_) => "location",
             OptionKind::FollowLocationTrusted(_) => "location-trusted",
@@ -766,6 +798,7 @@ impl OptionKind {
             OptionKind::Insecure(_) => "insecure",
             OptionKind::IpV4(_) => "ipv4",
             OptionKind::IpV6(_) => "ipv6",
+            OptionKind::LimitRate(_) => "limit-rate",
             OptionKind::MaxRedirect(_) => "max-redirs",
             OptionKind::NetRc(_) => "netrc",
             OptionKind::NetRcFile(_) => "netrc-file",
@@ -794,6 +827,7 @@ impl OptionKind {
             OptionKind::ClientKey(filename) => filename.to_string(),
             OptionKind::Compressed(value) => value.to_string(),
             OptionKind::ConnectTo(value) => value.to_string(),
+            OptionKind::ConnectTimeout(value) => value.to_string(),
             OptionKind::Delay(value) => value.to_string(),
             OptionKind::FollowLocation(value) => value.to_string(),
             OptionKind::FollowLocationTrusted(value) => value.to_string(),
@@ -804,6 +838,7 @@ impl OptionKind {
             OptionKind::Insecure(value) => value.to_string(),
             OptionKind::IpV4(value) => value.to_string(),
             OptionKind::IpV6(value) => value.to_string(),
+            OptionKind::LimitRate(value) => value.to_string(),
             OptionKind::MaxRedirect(value) => value.to_string(),
             OptionKind::NetRc(value) => value.to_string(),
             OptionKind::NetRcFile(filename) => filename.to_string(),
@@ -830,29 +865,30 @@ impl OptionKind {
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum BooleanOption {
     Literal(bool),
-    Expression(Expr),
+    Placeholder(Placeholder),
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum NaturalOption {
     Literal(u64),
-    Expression(Expr),
+    Placeholder(Placeholder),
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum CountOption {
     Literal(Count),
-    Expression(Expr),
+    Placeholder(Placeholder),
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum DurationOption {
     Literal(Duration),
-    Expression(Expr),
+    Placeholder(Placeholder),
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct VariableDefinition {
+    pub source_info: SourceInfo,
     pub name: String,
     pub space0: Whitespace,
     pub space1: Whitespace,
