@@ -15,10 +15,15 @@
  * limitations under the License.
  *
  */
+use crate::ast::{
+    BooleanOption, CookieAttribute, CookieAttributeName, CookiePath, CountOption, DurationOption,
+    Expr, ExprKind, Float, Function, Hex, Method, MultilineString, MultilineStringAttribute,
+    MultilineStringKind, NaturalOption, Number, Placeholder, PredicateFuncValue, Regex, Status,
+    StatusValue, Template, TemplateElement, Variable, VariableDefinition, VariableValue, Version,
+    VersionValue,
+};
 use core::fmt;
 
-use crate::ast::core::*;
-
 impl fmt::Display for Method {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "{}", self.0)
@@ -74,7 +79,7 @@ impl fmt::Display for TemplateElement {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let s = match self {
             TemplateElement::String { value, .. } => value.clone(),
-            TemplateElement::Expression(value) => format!("{{{{{value}}}}}"),
+            TemplateElement::Placeholder(value) => format!("{{{{{value}}}}}"),
         };
         write!(f, "{s}")
     }
@@ -96,9 +101,39 @@ impl fmt::Display for Float {
     }
 }
 
+impl fmt::Display for Placeholder {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{}", self.expr)
+    }
+}
+
 impl fmt::Display for Expr {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "{}", self.variable.name)
+        write!(f, "{}", self.kind)
+    }
+}
+
+impl fmt::Display for ExprKind {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        match self {
+            ExprKind::Variable(variable) => write!(f, "{}", variable),
+            ExprKind::Function(function) => write!(f, "{}", function),
+        }
+    }
+}
+
+impl fmt::Display for Variable {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{}", self.name)
+    }
+}
+
+impl fmt::Display for Function {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        match self {
+            Function::NewDate => write!(f, "newDate"),
+            Function::NewUuid => write!(f, "newUuid"),
+        }
     }
 }
 
@@ -181,7 +216,7 @@ impl fmt::Display for BooleanOption {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             BooleanOption::Literal(v) => write!(f, "{}", v),
-            BooleanOption::Expression(v) => write!(f, "{}", v),
+            BooleanOption::Placeholder(v) => write!(f, "{}", v),
         }
     }
 }
@@ -190,7 +225,7 @@ impl fmt::Display for NaturalOption {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             NaturalOption::Literal(v) => write!(f, "{}", v),
-            NaturalOption::Expression(v) => write!(f, "{}", v),
+            NaturalOption::Placeholder(v) => write!(f, "{}", v),
         }
     }
 }
@@ -199,7 +234,7 @@ impl fmt::Display for CountOption {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             CountOption::Literal(v) => write!(f, "{}", v),
-            CountOption::Expression(v) => write!(f, "{}", v),
+            CountOption::Placeholder(v) => write!(f, "{}", v),
         }
     }
 }
@@ -208,7 +243,7 @@ impl fmt::Display for DurationOption {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             DurationOption::Literal(v) => write!(f, "{}", v),
-            DurationOption::Expression(v) => write!(f, "{}", v),
+            DurationOption::Placeholder(v) => write!(f, "{}", v),
         }
     }
 }
@@ -298,6 +333,7 @@ impl PredicateFuncValue {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::ast::{CookieAttributeName, SourceInfo, Whitespace};
     use crate::reader::Pos;
 
     fn whitespace() -> Whitespace {
@@ -307,11 +343,14 @@ mod tests {
         }
     }
 
-    fn variable_expr() -> Expr {
-        Expr {
+    fn variable_placeholder() -> Placeholder {
+        Placeholder {
             space0: whitespace(),
-            variable: Variable {
-                name: "name".to_string(),
+            expr: Expr {
+                kind: ExprKind::Variable(Variable {
+                    name: "name".to_string(),
+                    source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                }),
                 source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
             },
             space1: whitespace(),
@@ -326,7 +365,7 @@ mod tests {
                     value: "Hello ".to_string(),
                     encoded: "Hello ".to_string(),
                 },
-                TemplateElement::Expression(variable_expr()),
+                TemplateElement::Placeholder(variable_placeholder()),
                 TemplateElement::String {
                     value: "!".to_string(),
                     encoded: "!".to_string(),
