@@ -18,7 +18,7 @@
 use core::fmt;
 
 use crate::ast::core::Template;
-use crate::ast::{Expr, TemplateElement};
+use crate::ast::{Placeholder, TemplateElement};
 
 ///
 /// This the AST for the JSON used within Hurl
@@ -28,7 +28,7 @@ use crate::ast::{Expr, TemplateElement};
 ///
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum Value {
-    Expression(Expr),
+    Placeholder(Placeholder),
     Number(String),
     String(Template),
     Boolean(bool),
@@ -52,7 +52,7 @@ impl Value {
             Value::List { .. } => "list".to_string(),
             Value::Object { .. } => "object".to_string(),
             Value::String(_) => "string".to_string(),
-            Value::Expression(_) => "expression".to_string(),
+            Value::Placeholder(_) => "placeholder".to_string(),
         }
     }
 }
@@ -77,7 +77,7 @@ pub struct ObjectElement {
 impl fmt::Display for Value {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let s = match self {
-            Value::Expression(expr) => format!("{{{{{expr}}}}}"),
+            Value::Placeholder(expr) => format!("{{{{{expr}}}}}"),
             Value::Number(s) => s.to_string(),
             Value::String(template) => format!("\"{template}\""),
             Value::Boolean(value) => {
@@ -136,7 +136,7 @@ impl fmt::Display for ObjectElement {
 impl Value {
     pub fn encoded(&self) -> String {
         match self {
-            Value::Expression(expr) => format!("{{{{{expr}}}}}"),
+            Value::Placeholder(expr) => format!("{{{{{expr}}}}}"),
             Value::Number(s) => s.to_string(),
             Value::String(template) => template.encoded(),
             Value::Boolean(value) => {
@@ -208,7 +208,7 @@ impl TemplateElement {
     fn encoded(&self) -> String {
         match self {
             TemplateElement::String { encoded, .. } => encoded.to_string(),
-            TemplateElement::Expression(expr) => format!("{{{{{expr}}}}}"),
+            TemplateElement::Placeholder(expr) => format!("{{{{{expr}}}}}"),
         }
     }
 }
@@ -216,21 +216,24 @@ impl TemplateElement {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::ast::{SourceInfo, TemplateElement, Variable, Whitespace};
+    use crate::ast::{Expr, ExprKind, SourceInfo, TemplateElement, Variable, Whitespace};
     use crate::reader::Pos;
 
     #[test]
     fn test_to_string() {
         assert_eq!(
             "{{x}}".to_string(),
-            Value::Expression(Expr {
+            Value::Placeholder(Placeholder {
                 space0: Whitespace {
                     value: String::new(),
                     source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
                 },
-                variable: Variable {
-                    name: "x".to_string(),
-                    source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                expr: Expr {
+                    kind: ExprKind::Variable(Variable {
+                        name: "x".to_string(),
+                        source_info: SourceInfo::new(Pos::new(0, 0), Pos::new(0, 0)),
+                    }),
+                    source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 1)),
                 },
                 space1: Whitespace {
                     value: String::new(),
@@ -321,13 +324,16 @@ mod tests {
     #[test]
     fn test_encoded() {
         assert_eq!(
-            TemplateElement::Expression(Expr {
+            TemplateElement::Placeholder(Placeholder {
                 space0: Whitespace {
                     value: String::new(),
                     source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 1)),
                 },
-                variable: Variable {
-                    name: "name".to_string(),
+                expr: Expr {
+                    kind: ExprKind::Variable(Variable {
+                        name: "name".to_string(),
+                        source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 1)),
+                    }),
                     source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 1)),
                 },
                 space1: Whitespace {
@@ -341,13 +347,16 @@ mod tests {
         assert_eq!(
             Template {
                 delimiter: None,
-                elements: vec![TemplateElement::Expression(Expr {
+                elements: vec![TemplateElement::Placeholder(Placeholder {
                     space0: Whitespace {
                         value: String::new(),
                         source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 1)),
                     },
-                    variable: Variable {
-                        name: "name".to_string(),
+                    expr: Expr {
+                        kind: ExprKind::Variable(Variable {
+                            name: "name".to_string(),
+                            source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 1)),
+                        }),
                         source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 1)),
                     },
                     space1: Whitespace {
