@@ -15,10 +15,17 @@
  * limitations under the License.
  *
  */
-use std::fmt::Display;
-
-use crate::ast::*;
+use crate::ast::{
+    Assert, Base64, Body, BooleanOption, Bytes, Capture, CertificateAttributeName, Comment, Cookie,
+    CookieAttribute, CookiePath, CountOption, DurationOption, Entry, EntryOption, File, FileParam,
+    FileValue, Filter, FilterValue, GraphQl, GraphQlVariables, Hex, HurlFile, JsonValue, KeyValue,
+    LineTerminator, Method, MultilineString, MultilineStringKind, MultipartParam, NaturalOption,
+    OptionKind, Placeholder, Predicate, PredicateFunc, PredicateFuncValue, PredicateValue, Query,
+    QueryValue, Regex, RegexValue, Request, Response, Section, SectionValue, Status, Template,
+    TemplateElement, VariableDefinition, VariableValue, Version, Whitespace,
+};
 use crate::typing::Count;
+use std::fmt::Display;
 
 /// Returns an HTML string of the Hurl file `hurl_file`.
 ///
@@ -175,14 +182,14 @@ impl HtmlFormatter {
     fn fmt_section_value(&mut self, section_value: &SectionValue) {
         match section_value {
             SectionValue::Asserts(items) => items.iter().for_each(|item| self.fmt_assert(item)),
-            SectionValue::QueryParams(items) => items.iter().for_each(|item| self.fmt_kv(item)),
+            SectionValue::QueryParams(items, _) => items.iter().for_each(|item| self.fmt_kv(item)),
             SectionValue::BasicAuth(item) => {
                 if let Some(kv) = item {
                     self.fmt_kv(kv);
                 }
             }
-            SectionValue::FormParams(items) => items.iter().for_each(|item| self.fmt_kv(item)),
-            SectionValue::MultipartFormData(items) => {
+            SectionValue::FormParams(items, _) => items.iter().for_each(|item| self.fmt_kv(item)),
+            SectionValue::MultipartFormData(items, _) => {
                 items.iter().for_each(|item| self.fmt_multipart_param(item));
             }
             SectionValue::Cookies(items) => items.iter().for_each(|item| self.fmt_cookie(item)),
@@ -221,6 +228,7 @@ impl HtmlFormatter {
             OptionKind::ClientKey(filename) => self.fmt_filename(filename),
             OptionKind::Compressed(value) => self.fmt_bool_option(value),
             OptionKind::ConnectTo(value) => self.fmt_template(value),
+            OptionKind::ConnectTimeout(value) => self.fmt_duration_option(value),
             OptionKind::Delay(value) => self.fmt_duration_option(value),
             OptionKind::FollowLocation(value) => self.fmt_bool_option(value),
             OptionKind::FollowLocationTrusted(value) => self.fmt_bool_option(value),
@@ -231,6 +239,7 @@ impl HtmlFormatter {
             OptionKind::Insecure(value) => self.fmt_bool_option(value),
             OptionKind::IpV4(value) => self.fmt_bool_option(value),
             OptionKind::IpV6(value) => self.fmt_bool_option(value),
+            OptionKind::LimitRate(value) => self.fmt_natural_option(value),
             OptionKind::MaxRedirect(value) => self.fmt_count_option(value),
             OptionKind::NetRc(value) => self.fmt_bool_option(value),
             OptionKind::NetRcFile(filename) => self.fmt_filename(filename),
@@ -256,7 +265,7 @@ impl HtmlFormatter {
     fn fmt_count_option(&mut self, count_option: &CountOption) {
         match count_option {
             CountOption::Literal(repeat) => self.fmt_count(*repeat),
-            CountOption::Expression(expr) => self.fmt_expr(expr),
+            CountOption::Placeholder(placeholder) => self.fmt_placeholder(placeholder),
         }
     }
 
@@ -269,8 +278,9 @@ impl HtmlFormatter {
 
     fn fmt_variable_definition(&mut self, option: &VariableDefinition) {
         self.buffer.push_str(option.name.as_str());
-        self.fmt_space(&option.space1);
+        self.fmt_space(&option.space0);
         self.buffer.push('=');
+        self.fmt_space(&option.space1);
         self.fmt_variable_value(&option.value);
     }
 
@@ -547,7 +557,7 @@ impl HtmlFormatter {
             PredicateValue::File(value) => self.fmt_file(value),
             PredicateValue::Hex(value) => self.fmt_hex(value),
             PredicateValue::Base64(value) => self.fmt_base64(value),
-            PredicateValue::Expression(value) => self.fmt_expr(value),
+            PredicateValue::Placeholder(value) => self.fmt_placeholder(value),
             PredicateValue::Null => self.fmt_span("null", "null"),
             PredicateValue::Regex(value) => self.fmt_regex(value),
         };
@@ -683,7 +693,14 @@ impl HtmlFormatter {
     fn fmt_bool_option(&mut self, value: &BooleanOption) {
         match value {
             BooleanOption::Literal(value) => self.fmt_span("boolean", &value.to_string()),
-            BooleanOption::Expression(value) => self.fmt_expr(value),
+            BooleanOption::Placeholder(value) => self.fmt_placeholder(value),
+        }
+    }
+
+    fn fmt_natural_option(&mut self, value: &NaturalOption) {
+        match value {
+            NaturalOption::Literal(value) => self.fmt_span("number", &value.to_string()),
+            NaturalOption::Placeholder(value) => self.fmt_placeholder(value),
         }
     }
 
@@ -695,7 +712,7 @@ impl HtmlFormatter {
                     self.fmt_span("unit", &unit.to_string());
                 }
             }
-            DurationOption::Expression(value) => self.fmt_expr(value),
+            DurationOption::Placeholder(value) => self.fmt_placeholder(value),
         }
     }
 
@@ -768,9 +785,9 @@ impl HtmlFormatter {
         self.fmt_string(&escape_xml(&s));
     }
 
-    fn fmt_expr(&mut self, expr: &Expr) {
-        let expr = format!("{{{{{}}}}}", &expr.to_string());
-        self.fmt_span("expr", &expr);
+    fn fmt_placeholder(&mut self, placeholder: &Placeholder) {
+        let placeholder = format!("{{{{{}}}}}", &placeholder.to_string());
+        self.fmt_span("expr", &placeholder);
     }
 
     fn fmt_filter(&mut self, filter: &Filter) {
@@ -870,7 +887,7 @@ impl Template {
         for element in self.elements.iter() {
             let elem_str = match element {
                 TemplateElement::String { encoded, .. } => encoded.to_string(),
-                TemplateElement::Expression(expr) => format!("{{{{{expr}}}}}"),
+                TemplateElement::Placeholder(expr) => format!("{{{{{expr}}}}}"),
             };
             s.push_str(elem_str.as_str());
         }
@@ -935,6 +952,7 @@ fn pop_str(string: &mut String, suffix: &str) {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::ast::{JsonObjectElement, SourceInfo, Text};
     use crate::reader::Pos;
 
     #[test]
