@@ -15,7 +15,7 @@
  * limitations under the License.
  *
  */
-use super::reader::Reader;
+use crate::reader::Reader;
 
 /// <https://en.wikipedia.org/wiki/Base64>
 /// Test padding/no-padding
@@ -31,7 +31,7 @@ pub fn parse(reader: &mut Reader) -> Vec<u8> {
         if !pad.is_empty() {
             break;
         }
-        let save = reader.state;
+        let save = reader.cursor();
         match reader.read() {
             None => {
                 break;
@@ -39,7 +39,7 @@ pub fn parse(reader: &mut Reader) -> Vec<u8> {
             Some(' ') | Some('\n') | Some('\t') => {}
             Some(c) => match value(c) {
                 None => {
-                    reader.state = save;
+                    reader.seek(save);
                     break;
                 }
                 Some(v) => {
@@ -142,13 +142,13 @@ fn padding(reader: &mut Reader) -> String {
     // consume padding can not fail
     let mut buf = String::new();
     loop {
-        let save = reader.state;
+        let save = reader.cursor();
         match reader.read() {
             Some('=') => {
                 buf.push('=');
             }
             _ => {
-                reader.state = save;
+                reader.seek(save);
                 break;
             }
         }
@@ -183,27 +183,27 @@ mod tests {
     fn test_decode_one_block() {
         let mut reader = Reader::new("");
         assert_eq!(parse(&mut reader), vec![] as Vec<u8>);
-        assert_eq!(reader.state.cursor, 0);
+        assert_eq!(reader.cursor().index, 0);
 
         let mut reader = Reader::new("AA==;");
         assert_eq!(parse(&mut reader), vec![0]);
-        assert_eq!(reader.state.cursor, 4);
+        assert_eq!(reader.cursor().index, 4);
 
         let mut reader = Reader::new("AA");
         assert_eq!(parse(&mut reader), vec![0]);
-        assert_eq!(reader.state.cursor, 2);
+        assert_eq!(reader.cursor().index, 2);
 
         let mut reader = Reader::new("AA;");
         assert_eq!(parse(&mut reader), vec![0]);
-        assert_eq!(reader.state.cursor, 2);
+        assert_eq!(reader.cursor().index, 2);
 
         let mut reader = Reader::new("TWE=;");
         assert_eq!(parse(&mut reader), vec![77, 97]);
-        assert_eq!(reader.state.cursor, 4);
+        assert_eq!(reader.cursor().index, 4);
 
         let mut reader = Reader::new("TWFu;");
         assert_eq!(parse(&mut reader), vec![77, 97, 110]);
-        assert_eq!(reader.state.cursor, 4);
+        assert_eq!(reader.cursor().index, 4);
     }
 
     /*
@@ -246,7 +246,7 @@ mod tests {
     fn test_decode_with_whitespace() {
         let mut reader = Reader::new("TW E=\n;");
         assert_eq!(parse(&mut reader), vec![77, 97]);
-        assert_eq!(reader.state.cursor, 5);
+        assert_eq!(reader.cursor().index, 5);
     }
 
     #[test]
