@@ -15,13 +15,13 @@
  * limitations under the License.
  *
  */
-use crate::ast::*;
-use crate::parser::error::*;
+use crate::ast::{SourceInfo, Template, TemplateElement};
 use crate::parser::primitives::try_literal;
-use crate::parser::template::template;
-use crate::parser::{string, ParseResult};
+use crate::parser::{string, ParseError, ParseErrorKind, ParseResult};
 use crate::reader::Reader;
 
+use super::placeholder;
+
 /// Parse a filename.
 ///
 /// A few characters need to be escaped such as space
@@ -34,9 +34,9 @@ pub fn parse(reader: &mut Reader) -> ParseResult<Template> {
     let mut elements = vec![];
     loop {
         let start = reader.cursor();
-        match template(reader) {
-            Ok(expr) => {
-                let element = TemplateElement::Expression(expr);
+        match placeholder::parse(reader) {
+            Ok(placeholder) => {
+                let element = TemplateElement::Placeholder(placeholder);
                 elements.push(element);
             }
             Err(e) => {
@@ -148,6 +148,7 @@ fn filename_escaped_char(reader: &mut Reader) -> ParseResult<char> {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::ast::{Expr, ExprKind, Placeholder, Variable, Whitespace};
     use crate::reader::Pos;
 
     #[test]
@@ -241,13 +242,16 @@ mod tests {
                         value: "foo_".to_string(),
                         encoded: "foo_".to_string(),
                     },
-                    TemplateElement::Expression(Expr {
+                    TemplateElement::Placeholder(Placeholder {
                         space0: Whitespace {
                             value: String::new(),
                             source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 7)),
                         },
-                        variable: Variable {
-                            name: "bar".to_string(),
+                        expr: Expr {
+                            kind: ExprKind::Variable(Variable {
+                                name: "bar".to_string(),
+                                source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 10)),
+                            }),
                             source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 10)),
                         },
                         space1: Whitespace {
@@ -270,13 +274,16 @@ mod tests {
                         value: "foo_".to_string(),
                         encoded: "foo_".to_string(),
                     },
-                    TemplateElement::Expression(Expr {
+                    TemplateElement::Placeholder(Placeholder {
                         space0: Whitespace {
                             value: String::new(),
                             source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 7)),
                         },
-                        variable: Variable {
-                            name: "bar".to_string(),
+                        expr: Expr {
+                            kind: ExprKind::Variable(Variable {
+                                name: "bar".to_string(),
+                                source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 10)),
+                            }),
                             source_info: SourceInfo::new(Pos::new(1, 7), Pos::new(1, 10)),
                         },
                         space1: Whitespace {
