@@ -15,13 +15,13 @@
  * limitations under the License.
  *
  */
-use crate::ast::*;
-use crate::parser::error::*;
+use crate::ast::{SourceInfo, Template, TemplateElement};
 use crate::parser::primitives::try_literal;
-use crate::parser::template::template;
-use crate::parser::{string, ParseResult};
+use crate::parser::{string, ParseError, ParseErrorKind, ParseResult};
 use crate::reader::Reader;
 
+use super::placeholder;
+
 /// Parse a filename with an optional password
 ///
 /// This is very similar to the filename parser.
@@ -35,9 +35,9 @@ pub fn parse(reader: &mut Reader) -> ParseResult<Template> {
     let mut elements = vec![];
     loop {
         let start = reader.cursor();
-        match template(reader) {
-            Ok(expr) => {
-                let element = TemplateElement::Expression(expr);
+        match placeholder::parse(reader) {
+            Ok(placeholder) => {
+                let element = TemplateElement::Placeholder(placeholder);
                 elements.push(element);
             }
             Err(e) => {
@@ -115,7 +115,7 @@ fn filename_password_text(reader: &mut Reader) -> String {
         match reader.read() {
             None => break,
             Some(c) => {
-                if ['#', ';', '{', '}', '\n', '\\'].contains(&c) {
+                if ['#', ';', '{', '}', ' ', '\n', '\\'].contains(&c) {
                     reader.seek(save);
                     break;
                 } else {
@@ -173,4 +173,21 @@ mod tests {
         );
         assert_eq!(reader.cursor().index, 18);
     }
+
+    #[test]
+    fn test_parse() {
+        let mut reader = Reader::new("/etc/client-cert.pem #foo");
+        assert_eq!(
+            parse(&mut reader).unwrap(),
+            Template {
+                delimiter: None,
+                elements: vec![TemplateElement::String {
+                    value: "/etc/client-cert.pem".to_string(),
+                    encoded: "/etc/client-cert.pem".to_string()
+                }],
+                source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 21)),
+            }
+        );
+        assert_eq!(reader.cursor().index, 20);
+    }
 }
