@@ -17,12 +17,13 @@
  */
 use crate::ast::{JsonListElement, JsonObjectElement, JsonValue, SourceInfo, Template};
 use crate::combinator::{choice, non_recover, ParseError as ParseErrorTrait};
-use crate::parser::error::*;
-use crate::parser::primitives::*;
-use crate::parser::template::*;
-use crate::parser::{expr, ParseResult};
+use crate::parser::primitives::{boolean, hex_digit, literal, try_literal};
+use crate::parser::template::EncodedString;
+use crate::parser::{templatize, JsonErrorVariant, ParseError, ParseErrorKind, ParseResult};
 use crate::reader::{Pos, Reader};
 
+use super::placeholder;
+
 pub fn parse(reader: &mut Reader) -> ParseResult<JsonValue> {
     choice(
         &[
@@ -270,8 +271,8 @@ pub fn number_value(reader: &mut Reader) -> ParseResult<JsonValue> {
 }
 
 fn expression_value(reader: &mut Reader) -> ParseResult<JsonValue> {
-    let exp = expr::parse(reader)?;
-    Ok(JsonValue::Expression(exp))
+    let exp = placeholder::parse(reader)?;
+    Ok(JsonValue::Placeholder(exp))
 }
 
 fn list_value(reader: &mut Reader) -> ParseResult<JsonValue> {
@@ -478,13 +479,16 @@ mod tests {
                     value: "Hello ".to_string(),
                     encoded: "Hello\\u0020".to_string(),
                 },
-                TemplateElement::Expression(Expr {
+                TemplateElement::Placeholder(Placeholder {
                     space0: Whitespace {
                         value: String::new(),
                         source_info: SourceInfo::new(Pos::new(1, 15), Pos::new(1, 15)),
                     },
-                    variable: Variable {
-                        name: "name".to_string(),
+                    expr: Expr {
+                        kind: ExprKind::Variable(Variable {
+                            name: "name".to_string(),
+                            source_info: SourceInfo::new(Pos::new(1, 15), Pos::new(1, 19)),
+                        }),
                         source_info: SourceInfo::new(Pos::new(1, 15), Pos::new(1, 19)),
                     },
                     space1: Whitespace {
@@ -772,13 +776,16 @@ mod tests {
         let mut reader = Reader::new("{{n}}");
         assert_eq!(
             expression_value(&mut reader).unwrap(),
-            JsonValue::Expression(Expr {
+            JsonValue::Placeholder(Placeholder {
                 space0: Whitespace {
                     value: String::new(),
                     source_info: SourceInfo::new(Pos::new(1, 3), Pos::new(1, 3))
                 },
-                variable: Variable {
-                    name: "n".to_string(),
+                expr: Expr {
+                    kind: ExprKind::Variable(Variable {
+                        name: "n".to_string(),
+                        source_info: SourceInfo::new(Pos::new(1, 3), Pos::new(1, 4))
+                    }),
                     source_info: SourceInfo::new(Pos::new(1, 3), Pos::new(1, 4))
                 },
                 space1: Whitespace {
