@@ -40,12 +40,14 @@ mod expr;
 mod filename;
 mod filename_password;
 mod filter;
+mod function;
 mod json;
 mod key_string;
 mod multiline;
 mod number;
 mod option;
 mod parsers;
+mod placeholder;
 mod predicate;
 mod predicate_value;
 mod primitives;
@@ -53,5 +55,4 @@ mod query;
 mod sections;
 mod string;
 mod template;
-mod url;
 mod xml;
