@@ -15,17 +15,24 @@
  * limitations under the License.
  *
  */
-use crate::ast::*;
+use crate::ast::{
+    is_variable_reserved, BooleanOption, CountOption, DurationOption, EntryOption, NaturalOption,
+    OptionKind, SourceInfo, VariableDefinition, VariableValue,
+};
 use crate::combinator::{choice, non_recover};
 use crate::parser::duration::duration;
-use crate::parser::error::*;
-use crate::parser::number::{integer, number};
-use crate::parser::primitives::*;
-use crate::parser::string::*;
-use crate::parser::{expr, filename, filename_password, ParseResult};
+use crate::parser::number::{integer, natural, number};
+use crate::parser::primitives::{
+    boolean, line_terminator, literal, null, optional_line_terminators, try_literal,
+    zero_or_more_spaces,
+};
+use crate::parser::string::{quoted_template, unquoted_template};
+use crate::parser::{filename, filename_password, ParseError, ParseErrorKind, ParseResult};
 use crate::reader::Reader;
 use crate::typing::Count;
 
+use super::placeholder;
+
 /// Parse an option in an `[Options]` section.
 pub fn parse(reader: &mut Reader) -> ParseResult<EntryOption> {
     let line_terminators = optional_line_terminators(reader)?;
@@ -45,6 +52,7 @@ pub fn parse(reader: &mut Reader) -> ParseResult<EntryOption> {
         "cert" => option_cert(reader)?,
         "compressed" => option_compressed(reader)?,
         "connect-to" => option_connect_to(reader)?,
+        "connect-timeout" => option_connect_timeout(reader)?,
         "delay" => option_delay(reader)?,
         "insecure" => option_insecure(reader)?,
         "http1.0" => option_http_10(reader)?,
@@ -54,6 +62,7 @@ pub fn parse(reader: &mut Reader) -> ParseResult<EntryOption> {
         "ipv4" => option_ipv4(reader)?,
         "ipv6" => option_ipv6(reader)?,
         "key" => option_key(reader)?,
+        "limit-rate" => option_limit_rate(reader)?,
         "location" => option_follow_location(reader)?,
         "location-trusted" => option_follow_location_trusted(reader)?,
         "max-redirs" => option_max_redirect(reader)?,
@@ -118,6 +127,11 @@ fn option_connect_to(reader: &mut Reader) -> ParseResult<OptionKind> {
     Ok(OptionKind::ConnectTo(value))
 }
 
+fn option_connect_timeout(reader: &mut Reader) -> ParseResult<OptionKind> {
+    let value = duration_option(reader)?;
+    Ok(OptionKind::ConnectTimeout(value))
+}
+
 fn option_delay(reader: &mut Reader) -> ParseResult<OptionKind> {
     let value = duration_option(reader)?;
     Ok(OptionKind::Delay(value))
@@ -173,6 +187,11 @@ fn option_key(reader: &mut Reader) -> ParseResult<OptionKind> {
     Ok(OptionKind::ClientKey(value))
 }
 
+fn option_limit_rate(reader: &mut Reader) -> ParseResult<OptionKind> {
+    let value = non_recover(natural_option, reader)?;
+    Ok(OptionKind::LimitRate(value))
+}
+
 fn option_max_redirect(reader: &mut Reader) -> ParseResult<OptionKind> {
     let value = non_recover(count_option, reader)?;
     Ok(OptionKind::MaxRedirect(value))
@@ -279,13 +298,30 @@ fn boolean_option(reader: &mut Reader) -> ParseResult<BooleanOption> {
         Ok(v) => Ok(BooleanOption::Literal(v)),
         Err(_) => {
             reader.seek(start);
-            let exp = expr::parse(reader).map_err(|e| {
+            let exp = placeholder::parse(reader).map_err(|e| {
                 let kind = ParseErrorKind::Expecting {
                     value: "true|false".to_string(),
                 };
                 ParseError::new(e.pos, false, kind)
             })?;
-            Ok(BooleanOption::Expression(exp))
+            Ok(BooleanOption::Placeholder(exp))
+        }
+    }
+}
+
+fn natural_option(reader: &mut Reader) -> ParseResult<NaturalOption> {
+    let start = reader.cursor();
+    match natural(reader) {
+        Ok(v) => Ok(NaturalOption::Literal(v)),
+        Err(_) => {
+            reader.seek(start);
+            let placeholder = placeholder::parse(reader).map_err(|e| {
+                let kind = ParseErrorKind::Expecting {
+                    value: "integer >= 0".to_string(),
+                };
+                ParseError::new(e.pos, false, kind)
+            })?;
+            Ok(NaturalOption::Placeholder(placeholder))
         }
     }
 }
@@ -296,13 +332,13 @@ fn count_option(reader: &mut Reader) -> ParseResult<CountOption> {
         Ok(v) => Ok(CountOption::Literal(v)),
         Err(_) => {
             reader.seek(start);
-            let exp = expr::parse(reader).map_err(|e| {
+            let placeholder = placeholder::parse(reader).map_err(|e| {
                 let kind = ParseErrorKind::Expecting {
                     value: "integer >= -1".to_string(),
                 };
                 ParseError::new(e.pos, false, kind)
             })?;
-            Ok(CountOption::Expression(exp))
+            Ok(CountOption::Placeholder(placeholder))
         }
     }
 }
@@ -314,13 +350,13 @@ fn duration_option(reader: &mut Reader) -> ParseResult<DurationOption> {
         Err(e) => {
             if e.recoverable {
                 reader.seek(start);
-                let exp = expr::parse(reader).map_err(|e| {
+                let placeholder = placeholder::parse(reader).map_err(|e| {
                     let kind = ParseErrorKind::Expecting {
                         value: "integer".to_string(),
                     };
                     ParseError::new(e.pos, false, kind)
                 })?;
-                Ok(DurationOption::Expression(exp))
+                Ok(DurationOption::Placeholder(placeholder))
             } else {
                 Err(e)
             }
@@ -329,12 +365,19 @@ fn duration_option(reader: &mut Reader) -> ParseResult<DurationOption> {
 }
 
 fn variable_definition(reader: &mut Reader) -> ParseResult<VariableDefinition> {
+    let start = reader.cursor();
     let name = variable_name(reader)?;
     let space0 = zero_or_more_spaces(reader)?;
     literal("=", reader)?;
     let space1 = zero_or_more_spaces(reader)?;
     let value = variable_value(reader)?;
+    let end = reader.cursor();
+    let source_info = SourceInfo {
+        start: start.pos,
+        end: end.pos,
+    };
     Ok(VariableDefinition {
+        source_info,
         name,
         space0,
         space1,
@@ -350,6 +393,11 @@ fn variable_name(reader: &mut Reader) -> ParseResult<String> {
             value: "variable name".to_string(),
         };
         return Err(ParseError::new(start.pos, false, kind));
+    } else if is_variable_reserved(&name) {
+        let kind = ParseErrorKind::Variable(format!(
+            "conflicts with the {name} function, use a different name"
+        ));
+        return Err(ParseError::new(start.pos, false, kind));
     }
     Ok(name)
 }
@@ -391,6 +439,7 @@ fn variable_value(reader: &mut Reader) -> ParseResult<VariableValue> {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::ast::{LineTerminator, Number, Template, TemplateElement, Whitespace};
     use crate::reader::Pos;
 
     #[test]
@@ -552,6 +601,29 @@ mod tests {
         assert!(!error.recoverable);
     }
 
+    #[test]
+    fn test_option_cert() {
+        let mut reader = Reader::new("/etc/client-cert.pem #foo");
+
+        assert_eq!(
+            option_cert(&mut reader).unwrap(),
+            OptionKind::ClientCert(Template {
+                delimiter: None,
+                elements: vec![TemplateElement::String {
+                    value: "/etc/client-cert.pem".to_string(),
+                    encoded: "/etc/client-cert.pem".to_string()
+                }],
+                source_info: SourceInfo {
+                    start: Pos { line: 1, column: 1 },
+                    end: Pos {
+                        line: 1,
+                        column: 21,
+                    },
+                },
+            }),
+        );
+    }
+
     #[test]
     fn test_option_retry_error() {
         let mut reader = Reader::new("retry: ###");
@@ -572,20 +644,15 @@ mod tests {
         assert_eq!(
             variable_definition(&mut reader).unwrap(),
             VariableDefinition {
+                source_info: SourceInfo::new(Pos::new(1, 1), Pos::new(1, 4)),
                 name: "a".to_string(),
                 space0: Whitespace {
                     value: String::new(),
-                    source_info: SourceInfo {
-                        start: Pos { line: 1, column: 2 },
-                        end: Pos { line: 1, column: 2 },
-                    },
+                    source_info: SourceInfo::new(Pos::new(1, 2), Pos::new(1, 2)),
                 },
                 space1: Whitespace {
                     value: String::new(),
-                    source_info: SourceInfo {
-                        start: Pos { line: 1, column: 3 },
-                        end: Pos { line: 1, column: 3 },
-                    },
+                    source_info: SourceInfo::new(Pos::new(1, 3), Pos::new(1, 3)),
                 },
                 value: VariableValue::Number(Number::Integer(1)),
             }
