@@ -15,12 +15,15 @@
  * limitations under the License.
  *
  */
-use crate::ast::*;
+use crate::ast::{
+    Predicate, PredicateFunc, PredicateFuncValue, PredicateValue, SourceInfo, Whitespace,
+};
 use crate::combinator::choice;
-use crate::parser::error::*;
 use crate::parser::predicate_value::predicate_value;
-use crate::parser::primitives::*;
-use crate::parser::ParseResult;
+use crate::parser::primitives::{
+    one_or_more_spaces, try_literal, try_literals, zero_or_more_spaces,
+};
+use crate::parser::{ParseError, ParseErrorKind, ParseResult};
 use crate::reader::Reader;
 
 pub fn predicate(reader: &mut Reader) -> ParseResult<Predicate> {
@@ -114,7 +117,7 @@ impl PredicateValue {
     }
 
     pub fn is_expression(&self) -> bool {
-        matches!(self, PredicateValue::Expression(_))
+        matches!(self, PredicateValue::Placeholder(_))
     }
 }
 
@@ -382,6 +385,9 @@ fn is_number_predicate(reader: &mut Reader) -> ParseResult<PredicateFuncValue> {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::ast::{
+        Expr, ExprKind, Float, Number, Placeholder, Template, TemplateElement, Variable,
+    };
     use crate::reader::Pos;
 
     #[test]
@@ -520,13 +526,16 @@ mod tests {
         assert_eq!(
             equal_predicate(&mut reader).unwrap(),
             PredicateFuncValue::Equal {
-                value: PredicateValue::Expression(Expr {
+                value: PredicateValue::Placeholder(Placeholder {
                     space0: Whitespace {
                         value: String::new(),
                         source_info: SourceInfo::new(Pos::new(1, 6), Pos::new(1, 6)),
                     },
-                    variable: Variable {
-                        name: "count".to_string(),
+                    expr: Expr {
+                        kind: ExprKind::Variable(Variable {
+                            name: "count".to_string(),
+                            source_info: SourceInfo::new(Pos::new(1, 6), Pos::new(1, 11)),
+                        }),
                         source_info: SourceInfo::new(Pos::new(1, 6), Pos::new(1, 11)),
                     },
                     space1: Whitespace {
