@@ -15,15 +15,20 @@
  * limitations under the License.
  *
  */
-use crate::ast::*;
+use crate::ast::{
+    Assert, Capture, Cookie, FileParam, FileValue, MultipartParam, Section, SectionValue,
+    SourceInfo, Whitespace,
+};
 use crate::combinator::{optional, recover, zero_or_more};
-use crate::parser::error::*;
 use crate::parser::filter::filters;
 use crate::parser::predicate::predicate;
-use crate::parser::primitives::*;
+use crate::parser::primitives::{
+    key_value, line_terminator, literal, one_or_more_spaces, optional_line_terminators,
+    try_literal, zero_or_more_spaces,
+};
 use crate::parser::query::query;
-use crate::parser::string::*;
-use crate::parser::{filename, key_string, option, ParseResult};
+use crate::parser::string::unquoted_template;
+use crate::parser::{filename, key_string, option, ParseError, ParseErrorKind, ParseResult};
 use crate::reader::{Pos, Reader};
 
 pub fn request_sections(reader: &mut Reader) -> ParseResult<Vec<Section>> {
@@ -45,10 +50,13 @@ fn request_section(reader: &mut Reader) -> ParseResult<Section> {
 
     let line_terminator0 = line_terminator(reader)?;
     let value = match name.as_str() {
-        "QueryStringParams" => section_value_query_params(reader)?,
+        "Query" => section_value_query_params(reader, true)?,
+        "QueryStringParams" => section_value_query_params(reader, false)?,
         "BasicAuth" => section_value_basic_auth(reader)?,
-        "FormParams" => section_value_form_params(reader)?,
-        "MultipartFormData" => section_value_multipart_form_data(reader)?,
+        "Form" => section_value_form_params(reader, true)?,
+        "FormParams" => section_value_form_params(reader, false)?,
+        "Multipart" => section_value_multipart_form_data(reader, true)?,
+        "MultipartFormData" => section_value_multipart_form_data(reader, false)?,
         "Cookies" => section_value_cookies(reader)?,
         "Options" => section_value_options(reader)?,
         _ => {
@@ -110,9 +118,9 @@ fn section_name(reader: &mut Reader) -> ParseResult<String> {
     Ok(name)
 }
 
-fn section_value_query_params(reader: &mut Reader) -> ParseResult<SectionValue> {
+fn section_value_query_params(reader: &mut Reader, short: bool) -> ParseResult<SectionValue> {
     let items = zero_or_more(key_value, reader)?;
-    Ok(SectionValue::QueryParams(items))
+    Ok(SectionValue::QueryParams(items, short))
 }
 
 fn section_value_basic_auth(reader: &mut Reader) -> ParseResult<SectionValue> {
@@ -120,14 +128,17 @@ fn section_value_basic_auth(reader: &mut Reader) -> ParseResult<SectionValue> {
     Ok(SectionValue::BasicAuth(v))
 }
 
-fn section_value_form_params(reader: &mut Reader) -> ParseResult<SectionValue> {
+fn section_value_form_params(reader: &mut Reader, short: bool) -> ParseResult<SectionValue> {
     let items = zero_or_more(key_value, reader)?;
-    Ok(SectionValue::FormParams(items))
+    Ok(SectionValue::FormParams(items, short))
 }
 
-fn section_value_multipart_form_data(reader: &mut Reader) -> ParseResult<SectionValue> {
+fn section_value_multipart_form_data(
+    reader: &mut Reader,
+    short: bool,
+) -> ParseResult<SectionValue> {
     let items = zero_or_more(multipart_param, reader)?;
-    Ok(SectionValue::MultipartFormData(items))
+    Ok(SectionValue::MultipartFormData(items, short))
 }
 
 fn section_value_cookies(reader: &mut Reader) -> ParseResult<SectionValue> {
@@ -317,6 +328,10 @@ fn assert(reader: &mut Reader) -> ParseResult<Assert> {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::ast::{
+        KeyValue, LineTerminator, Number, Predicate, PredicateFunc, PredicateFuncValue,
+        PredicateValue, Query, QueryValue, Template, TemplateElement,
+    };
 
     #[test]
     fn test_section_name() {
