@@ -15,11 +15,10 @@
  * limitations under the License.
  *
  */
-use crate::ast::*;
+use crate::ast::{SourceInfo, Template};
 use crate::combinator::one_or_more;
-use crate::parser::error::*;
-use crate::parser::primitives::*;
-use crate::parser::{template, ParseResult};
+use crate::parser::primitives::{hex_digit, literal, try_literal};
+use crate::parser::{template, ParseError, ParseErrorKind, ParseResult};
 use crate::reader::Reader;
 
 /// Steps:
@@ -241,10 +240,10 @@ fn hex_value(reader: &mut Reader) -> ParseResult<u32> {
 
 #[cfg(test)]
 mod tests {
-    use std::time::SystemTime;
-
     use super::*;
+    use crate::ast::{Expr, ExprKind, Placeholder, TemplateElement, Variable, Whitespace};
     use crate::reader::Pos;
+    use std::time::SystemTime;
 
     #[test]
     fn test_unquoted_template_empty() {
@@ -323,13 +322,16 @@ mod tests {
                         value: "hello ".to_string(),
                         encoded: "hello\\u{20}".to_string(),
                     },
-                    TemplateElement::Expression(Expr {
+                    TemplateElement::Placeholder(Placeholder {
                         space0: Whitespace {
                             value: String::new(),
                             source_info: SourceInfo::new(Pos::new(1, 14), Pos::new(1, 14)),
                         },
-                        variable: Variable {
-                            name: "name".to_string(),
+                        expr: Expr {
+                            kind: ExprKind::Variable(Variable {
+                                name: "name".to_string(),
+                                source_info: SourceInfo::new(Pos::new(1, 14), Pos::new(1, 18)),
+                            }),
                             source_info: SourceInfo::new(Pos::new(1, 14), Pos::new(1, 18)),
                         },
                         space1: Whitespace {
