@@ -15,8 +15,8 @@
  * limitations under the License.
  *
  */
-use crate::ast::{Expr, SourceInfo, TemplateElement};
-use crate::parser::primitives::{literal, try_literal};
+use crate::ast::{Placeholder, SourceInfo, TemplateElement};
+use crate::parser::primitives::zero_or_more_spaces;
 use crate::parser::{error, expr, ParseResult};
 use crate::reader::{Pos, Reader};
 
@@ -25,13 +25,6 @@ pub struct EncodedString {
     pub chars: Vec<(char, String, Pos)>,
 }
 
-pub fn template(reader: &mut Reader) -> ParseResult<Expr> {
-    try_literal("{{", reader)?;
-    let expression = expr::parse2(reader)?;
-    literal("}}", reader)?;
-    Ok(expression)
-}
-
 pub fn templatize(encoded_string: EncodedString) -> ParseResult<Vec<TemplateElement>> {
     enum State {
         String,
@@ -91,8 +84,15 @@ pub fn templatize(encoded_string: EncodedString) -> ParseResult<Vec<TemplateElem
             State::FirstCloseBracket => {
                 if s.as_str() == "}" {
                     let mut reader = Reader::with_pos(encoded.as_str(), expression_start.unwrap());
-                    let expression = expr::parse2(&mut reader)?;
-                    elements.push(TemplateElement::Expression(expression));
+                    let space0 = zero_or_more_spaces(&mut reader)?;
+                    let expr = expr::parse(&mut reader)?;
+                    let space1 = zero_or_more_spaces(&mut reader)?;
+                    let placeholder = Placeholder {
+                        space0,
+                        expr,
+                        space1,
+                    };
+                    elements.push(TemplateElement::Placeholder(placeholder));
                     value = String::new();
                     encoded = String::new();
                     expression_start = None;
@@ -133,8 +133,9 @@ pub fn templatize(encoded_string: EncodedString) -> ParseResult<Vec<TemplateElem
 
 #[cfg(test)]
 mod tests {
+
     use super::*;
-    use crate::ast::{Expr, Variable, Whitespace};
+    use crate::ast::{Expr, ExprKind, Placeholder, Variable, Whitespace};
 
     #[test]
     fn test_templatize_empty_string() {
@@ -228,13 +229,16 @@ mod tests {
                     value: "Hi ".to_string(),
                     encoded: "Hi\\u0020".to_string(),
                 },
-                TemplateElement::Expression(Expr {
+                TemplateElement::Placeholder(Placeholder {
                     space0: Whitespace {
                         value: String::new(),
                         source_info: SourceInfo::new(Pos::new(1, 11), Pos::new(1, 11)),
                     },
-                    variable: Variable {
-                        name: "name".to_string(),
+                    expr: Expr {
+                        kind: ExprKind::Variable(Variable {
+                            name: "name".to_string(),
+                            source_info: SourceInfo::new(Pos::new(1, 11), Pos::new(1, 15)),
+                        }),
                         source_info: SourceInfo::new(Pos::new(1, 11), Pos::new(1, 15)),
                     },
                     space1: Whitespace {
@@ -265,14 +269,17 @@ mod tests {
         };
         assert_eq!(
             templatize(encoded_string).unwrap(),
-            vec![TemplateElement::Expression(Expr {
+            vec![TemplateElement::Placeholder(Placeholder {
                 space0: Whitespace {
                     value: String::new(),
                     source_info: SourceInfo::new(Pos::new(1, 3), Pos::new(1, 3)),
                 },
-                variable: Variable {
-                    name: "x".to_string(),
-                    source_info: SourceInfo::new(Pos::new(1, 3), Pos::new(1, 4)),
+                expr: Expr {
+                    kind: ExprKind::Variable(Variable {
+                        name: "x".to_string(),
+                        source_info: SourceInfo::new(Pos::new(1, 3), Pos::new(1, 4)),
+                    }),
+                    source_info: SourceInfo::new(Pos::new(1, 3), Pos::new(1, 4))
                 },
                 space1: Whitespace {
                     value: String::new(),
