@@ -15,13 +15,19 @@
  * limitations under the License.
  *
  */
+use crate::format::serialize_json::JValue;
 use base64::engine::general_purpose;
 use base64::Engine;
-use hurl_core::ast::*;
+use hurl_core::ast::{
+    Assert, Base64, Body, BooleanOption, Bytes, Capture, CertificateAttributeName, Comment, Cookie,
+    CountOption, DurationOption, Entry, EntryOption, File, FileParam, Filter, FilterValue, Header,
+    Hex, HurlFile, JsonListElement, JsonValue, KeyValue, MultilineString, MultilineStringKind,
+    MultipartParam, NaturalOption, OptionKind, Placeholder, Predicate, PredicateFuncValue,
+    PredicateValue, Query, QueryValue, Regex, RegexValue, Request, Response, StatusValue,
+    VersionValue,
+};
 use hurl_core::typing::{Count, Duration};
 
-use super::serialize_json::*;
-
 pub fn format(hurl_file: &HurlFile) -> String {
     hurl_file.to_json().format()
 }
@@ -304,6 +310,7 @@ impl ToJson for EntryOption {
             OptionKind::ClientKey(filename) => JValue::String(filename.to_string()),
             OptionKind::Compressed(value) => value.to_json(),
             OptionKind::ConnectTo(value) => JValue::String(value.to_string()),
+            OptionKind::ConnectTimeout(value) => value.to_json(),
             OptionKind::Delay(value) => value.to_json(),
             OptionKind::FollowLocation(value) => value.to_json(),
             OptionKind::FollowLocationTrusted(value) => value.to_json(),
@@ -314,6 +321,7 @@ impl ToJson for EntryOption {
             OptionKind::Insecure(value) => value.to_json(),
             OptionKind::IpV4(value) => value.to_json(),
             OptionKind::IpV6(value) => value.to_json(),
+            OptionKind::LimitRate(value) => value.to_json(),
             OptionKind::MaxRedirect(value) => value.to_json(),
             OptionKind::NetRc(value) => value.to_json(),
             OptionKind::NetRcFile(filename) => JValue::String(filename.to_string()),
@@ -361,7 +369,7 @@ impl ToJson for BooleanOption {
     fn to_json(&self) -> JValue {
         match self {
             BooleanOption::Literal(value) => JValue::Boolean(*value),
-            BooleanOption::Expression(expr) => expr.to_json(),
+            BooleanOption::Placeholder(placeholder) => placeholder.to_json(),
         }
     }
 }
@@ -370,7 +378,7 @@ impl ToJson for CountOption {
     fn to_json(&self) -> JValue {
         match self {
             CountOption::Literal(value) => value.to_json(),
-            CountOption::Expression(expr) => expr.to_json(),
+            CountOption::Placeholder(placeholder) => placeholder.to_json(),
         }
     }
 }
@@ -388,7 +396,7 @@ impl ToJson for DurationOption {
     fn to_json(&self) -> JValue {
         match self {
             DurationOption::Literal(value) => value.to_json(),
-            DurationOption::Expression(expr) => expr.to_json(),
+            DurationOption::Placeholder(placeholder) => placeholder.to_json(),
         }
     }
 }
@@ -652,7 +660,7 @@ fn json_predicate_value(predicate_value: PredicateValue) -> (JValue, Option<Stri
             let base64_string = general_purpose::STANDARD.encode(value.value);
             (JValue::String(base64_string), Some("base64".to_string()))
         }
-        PredicateValue::Expression(value) => (JValue::String(value.to_string()), None),
+        PredicateValue::Placeholder(value) => (JValue::String(value.to_string()), None),
         PredicateValue::Regex(value) => {
             (JValue::String(value.to_string()), Some("regex".to_string()))
         }
@@ -675,7 +683,7 @@ impl ToJson for JsonValue {
                     .map(|elem| (elem.name.to_string(), elem.value.to_json()))
                     .collect(),
             ),
-            JsonValue::Expression(exp) => JValue::String(format!("{{{{{exp}}}}}")),
+            JsonValue::Placeholder(exp) => JValue::String(format!("{{{{{exp}}}}}")),
         }
     }
 }
@@ -781,7 +789,7 @@ impl ToJson for FilterValue {
     }
 }
 
-impl ToJson for Expr {
+impl ToJson for Placeholder {
     fn to_json(&self) -> JValue {
         JValue::String(format!("{{{{{}}}}}", self))
     }
@@ -793,8 +801,20 @@ impl ToJson for Comment {
     }
 }
 
+impl ToJson for NaturalOption {
+    fn to_json(&self) -> JValue {
+        match self {
+            NaturalOption::Literal(value) => JValue::Number(value.to_string()),
+            NaturalOption::Placeholder(placeholder) => placeholder.to_json(),
+        }
+    }
+}
 #[cfg(test)]
 pub mod tests {
+    use hurl_core::ast::{
+        LineTerminator, Method, Number, PredicateFunc, SourceInfo, Status, Template,
+        TemplateElement, Version, Whitespace,
+    };
     use hurl_core::reader::Pos;
 
     use super::*;
