@@ -15,7 +15,17 @@
  * limitations under the License.
  *
  */
-use hurl_core::ast::*;
+use hurl_core::ast::{
+    Assert, Base64, Body, BooleanOption, Bytes, Capture, CertificateAttributeName, Comment, Cookie,
+    CookieAttribute, CookiePath, CountOption, DurationOption, EncodedString, Entry, EntryOption,
+    Expr, ExprKind, File, FileParam, FileValue, Filter, FilterValue, Function, GraphQl,
+    GraphQlVariables, Hex, HurlFile, JsonListElement, JsonObjectElement, JsonValue, KeyValue,
+    LineTerminator, Method, MultilineString, MultilineStringAttribute, MultilineStringKind,
+    MultipartParam, NaturalOption, OptionKind, Placeholder, Predicate, PredicateFunc,
+    PredicateFuncValue, PredicateValue, Query, QueryValue, Regex, RegexValue, Request, Response,
+    Section, SectionValue, Status, StatusValue, Template, TemplateElement, Text, Variable,
+    VariableDefinition, VariableValue, Version, Whitespace,
+};
 use hurl_core::typing::{Count, Duration};
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -204,7 +214,7 @@ impl Tokenizable for SectionValue {
             SectionValue::Asserts(items) => {
                 tokens.append(&mut items.iter().flat_map(|e| e.tokenize()).collect());
             }
-            SectionValue::QueryParams(items) => {
+            SectionValue::QueryParams(items, _) => {
                 tokens.append(&mut items.iter().flat_map(|e| e.tokenize()).collect());
             }
             SectionValue::BasicAuth(item) => {
@@ -212,10 +222,10 @@ impl Tokenizable for SectionValue {
                     tokens.append(&mut kv.tokenize());
                 }
             }
-            SectionValue::FormParams(items) => {
+            SectionValue::FormParams(items, _) => {
                 tokens.append(&mut items.iter().flat_map(|e| e.tokenize()).collect());
             }
-            SectionValue::MultipartFormData(items) => {
+            SectionValue::MultipartFormData(items, _) => {
                 tokens.append(&mut items.iter().flat_map(|e| e.tokenize()).collect());
             }
             SectionValue::Cookies(items) => {
@@ -629,7 +639,7 @@ impl Tokenizable for PredicateValue {
             PredicateValue::File(value) => value.tokenize(),
             PredicateValue::Hex(value) => vec![Token::String(value.to_string())],
             PredicateValue::Base64(value) => value.tokenize(),
-            PredicateValue::Expression(value) => value.tokenize(),
+            PredicateValue::Placeholder(value) => value.tokenize(),
             PredicateValue::Regex(value) => value.tokenize(),
         }
     }
@@ -752,7 +762,7 @@ impl Tokenizable for TemplateElement {
             TemplateElement::String { encoded, .. } => {
                 vec![Token::String(encoded.to_string())]
             }
-            TemplateElement::Expression(value) => {
+            TemplateElement::Placeholder(value) => {
                 let mut tokens: Vec<Token> = vec![];
                 tokens.append(&mut value.tokenize());
                 tokens
@@ -761,17 +771,47 @@ impl Tokenizable for TemplateElement {
     }
 }
 
-impl Tokenizable for Expr {
+impl Tokenizable for Placeholder {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![Token::CodeDelimiter(String::from("{{"))];
         tokens.append(&mut self.space0.tokenize());
-        tokens.push(Token::CodeVariable(self.variable.name.clone()));
+        tokens.append(&mut self.expr.tokenize());
         tokens.append(&mut self.space1.tokenize());
         tokens.push(Token::CodeDelimiter(String::from("}}")));
         tokens
     }
 }
 
+impl Tokenizable for Expr {
+    fn tokenize(&self) -> Vec<Token> {
+        self.kind.tokenize()
+    }
+}
+
+impl Tokenizable for ExprKind {
+    fn tokenize(&self) -> Vec<Token> {
+        match self {
+            ExprKind::Variable(variable) => variable.tokenize(),
+            ExprKind::Function(function) => function.tokenize(),
+        }
+    }
+}
+
+impl Tokenizable for Variable {
+    fn tokenize(&self) -> Vec<Token> {
+        vec![Token::CodeVariable(self.name.clone())]
+    }
+}
+
+impl Tokenizable for Function {
+    fn tokenize(&self) -> Vec<Token> {
+        match self {
+            Function::NewDate => vec![Token::CodeVariable("newDate".to_string())],
+            Function::NewUuid => vec![Token::CodeVariable("newUuid".to_string())],
+        }
+    }
+}
+
 impl Tokenizable for Regex {
     fn tokenize(&self) -> Vec<Token> {
         let s = str::replace(self.inner.as_str(), "/", "\\/");
@@ -847,7 +887,7 @@ impl Tokenizable for JsonValue {
             JsonValue::Null => {
                 tokens.push(Token::Keyword("null".to_string()));
             }
-            JsonValue::Expression(exp) => {
+            JsonValue::Placeholder(exp) => {
                 tokens.append(&mut exp.tokenize());
             }
         }
@@ -878,6 +918,7 @@ impl Tokenizable for JsonObjectElement {
         tokens
     }
 }
+
 impl Tokenizable for EntryOption {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -908,6 +949,7 @@ impl Tokenizable for OptionKind {
             OptionKind::ClientKey(filename) => filename.tokenize(),
             OptionKind::Compressed(value) => value.tokenize(),
             OptionKind::ConnectTo(value) => value.tokenize(),
+            OptionKind::ConnectTimeout(value) => value.tokenize(),
             OptionKind::Delay(value) => value.tokenize(),
             OptionKind::FollowLocation(value) => value.tokenize(),
             OptionKind::FollowLocationTrusted(value) => value.tokenize(),
@@ -918,6 +960,7 @@ impl Tokenizable for OptionKind {
             OptionKind::Insecure(value) => value.tokenize(),
             OptionKind::IpV4(value) => value.tokenize(),
             OptionKind::IpV6(value) => value.tokenize(),
+            OptionKind::LimitRate(value) => value.tokenize(),
             OptionKind::MaxRedirect(value) => value.tokenize(),
             OptionKind::NetRc(value) => value.tokenize(),
             OptionKind::NetRcFile(filename) => filename.tokenize(),
@@ -943,7 +986,7 @@ impl Tokenizable for BooleanOption {
     fn tokenize(&self) -> Vec<Token> {
         match self {
             BooleanOption::Literal(value) => vec![Token::Boolean(value.to_string())],
-            BooleanOption::Expression(expr) => expr.tokenize(),
+            BooleanOption::Placeholder(expr) => expr.tokenize(),
         }
     }
 }
@@ -952,7 +995,7 @@ impl Tokenizable for NaturalOption {
     fn tokenize(&self) -> Vec<Token> {
         match self {
             NaturalOption::Literal(value) => vec![Token::Number(value.to_string())],
-            NaturalOption::Expression(expr) => expr.tokenize(),
+            NaturalOption::Placeholder(expr) => expr.tokenize(),
         }
     }
 }
@@ -961,7 +1004,7 @@ impl Tokenizable for CountOption {
     fn tokenize(&self) -> Vec<Token> {
         match self {
             CountOption::Literal(retry) => retry.tokenize(),
-            CountOption::Expression(expr) => expr.tokenize(),
+            CountOption::Placeholder(expr) => expr.tokenize(),
         }
     }
 }
@@ -979,7 +1022,7 @@ impl Tokenizable for DurationOption {
     fn tokenize(&self) -> Vec<Token> {
         match self {
             DurationOption::Literal(value) => value.tokenize(),
-            DurationOption::Expression(expr) => expr.tokenize(),
+            DurationOption::Placeholder(expr) => expr.tokenize(),
         }
     }
 }
