@@ -16,7 +16,14 @@
  *
  */
 use crate::linter::{LinterError, LinterErrorKind};
-use hurl_core::ast::*;
+use hurl_core::ast::{
+    Assert, Base64, Body, Bytes, Capture, Comment, Cookie, CookieAttribute, CookieAttributeName,
+    CookiePath, DurationOption, Entry, EntryOption, File, FileParam, Filter, FilterValue, GraphQl,
+    Hex, HurlFile, KeyValue, LineTerminator, MultilineString, MultilineStringAttribute,
+    MultilineStringKind, MultipartParam, OptionKind, Predicate, PredicateFunc, PredicateFuncValue,
+    PredicateValue, Query, QueryValue, RegexValue, Request, Response, Section, SectionValue,
+    SourceInfo, Template, Text, VariableDefinition, Whitespace,
+};
 use hurl_core::reader::Pos;
 use hurl_core::typing::{Duration, DurationUnit};
 
@@ -36,10 +43,9 @@ pub fn lint_hurl_file(hurl_file: &HurlFile) -> HurlFile {
 fn check_entry(entry: &Entry) -> Vec<LinterError> {
     let mut errors = vec![];
     errors.append(&mut check_request(&entry.request));
-    match &entry.response {
-        Some(r) => errors.append(&mut check_response(r)),
-        None => {}
-    };
+    if let Some(response) = &entry.response {
+        errors.append(&mut check_response(response));
+    }
     errors
 }
 
@@ -165,8 +171,8 @@ fn lint_section(section: &Section) -> Section {
 
 fn lint_section_value(section_value: &SectionValue) -> SectionValue {
     match section_value {
-        SectionValue::QueryParams(params) => {
-            SectionValue::QueryParams(params.iter().map(lint_key_value).collect())
+        SectionValue::QueryParams(params, short) => {
+            SectionValue::QueryParams(params.iter().map(lint_key_value).collect(), *short)
         }
         SectionValue::BasicAuth(param) => {
             SectionValue::BasicAuth(param.as_ref().map(lint_key_value))
@@ -177,12 +183,13 @@ fn lint_section_value(section_value: &SectionValue) -> SectionValue {
         SectionValue::Asserts(asserts) => {
             SectionValue::Asserts(asserts.iter().map(lint_assert).collect())
         }
-        SectionValue::FormParams(params) => {
-            SectionValue::FormParams(params.iter().map(lint_key_value).collect())
-        }
-        SectionValue::MultipartFormData(params) => {
-            SectionValue::MultipartFormData(params.iter().map(lint_multipart_param).collect())
+        SectionValue::FormParams(params, short) => {
+            SectionValue::FormParams(params.iter().map(lint_key_value).collect(), *short)
         }
+        SectionValue::MultipartFormData(params, short) => SectionValue::MultipartFormData(
+            params.iter().map(lint_multipart_param).collect(),
+            *short,
+        ),
         SectionValue::Cookies(cookies) => {
             SectionValue::Cookies(cookies.iter().map(lint_cookie).collect())
         }
@@ -196,10 +203,10 @@ fn section_value_index(section_value: SectionValue) -> u32 {
     match section_value {
         // Request sections
         SectionValue::Options(_) => 0,
-        SectionValue::QueryParams(_) => 1,
+        SectionValue::QueryParams(_, _) => 1,
         SectionValue::BasicAuth(_) => 2,
-        SectionValue::FormParams(_) => 3,
-        SectionValue::MultipartFormData(_) => 4,
+        SectionValue::FormParams(_, _) => 3,
+        SectionValue::MultipartFormData(_, _) => 4,
         SectionValue::Cookies(_) => 5,
         // Response sections
         SectionValue::Captures(_) => 0,
@@ -432,7 +439,7 @@ fn lint_predicate_value(predicate_value: &PredicateValue) -> PredicateValue {
         PredicateValue::File(value) => PredicateValue::File(lint_file(value)),
         PredicateValue::Hex(value) => PredicateValue::Hex(lint_hex(value)),
         PredicateValue::Base64(value) => PredicateValue::Base64(lint_base64(value)),
-        PredicateValue::Expression(value) => PredicateValue::Expression(value.clone()),
+        PredicateValue::Placeholder(value) => PredicateValue::Placeholder(value.clone()),
         PredicateValue::Regex(value) => PredicateValue::Regex(value.clone()),
     }
 }
@@ -687,6 +694,7 @@ fn lint_option_kind(option_kind: &OptionKind) -> OptionKind {
         OptionKind::RetryInterval(duration) => {
             OptionKind::RetryInterval(lint_duration_option(duration, DurationUnit::MilliSecond))
         }
+        OptionKind::Variable(var_def) => OptionKind::Variable(lint_variable_definition(var_def)),
         _ => option_kind.clone(),
     }
 }
@@ -699,7 +707,7 @@ fn lint_duration_option(
         DurationOption::Literal(duration) => {
             DurationOption::Literal(lint_duration(duration, default_unit))
         }
-        DurationOption::Expression(expr) => DurationOption::Expression(expr.clone()),
+        DurationOption::Placeholder(expr) => DurationOption::Placeholder(expr.clone()),
     }
 }
 
@@ -726,6 +734,14 @@ fn lint_filter_value(filter_value: &FilterValue) -> FilterValue {
     }
 }
 
+fn lint_variable_definition(var_def: &VariableDefinition) -> VariableDefinition {
+    VariableDefinition {
+        space0: empty_whitespace(),
+        space1: empty_whitespace(),
+        ..var_def.clone()
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
